@@ -8,8 +8,7 @@ use std::ops::{Add, AddAssign, Div, Mul, Sub, SubAssign};
 use arrow::array::PrimitiveArray;
 use arrow::bitmap::{Bitmap, MutableBitmap};
 use arrow::types::NativeType;
-use num::ToPrimitive;
-use num::{Bounded, Float, NumCast, One, Zero};
+use num::{Bounded, Float, NumCast, One, ToPrimitive, Zero};
 use window::*;
 
 use crate::data_types::IsFloat;
@@ -22,9 +21,11 @@ type Idx = usize;
 type WindowSize = usize;
 type Len = usize;
 
-fn compare_fn_nan_min<T>(a: &T, b: &T) -> Ordering
+#[inline]
+/// NaN will be smaller than every valid value
+pub fn compare_fn_nan_min<T>(a: &T, b: &T) -> Ordering
 where
-    T: PartialOrd + IsFloat + NativeType,
+    T: PartialOrd + IsFloat,
 {
     if T::is_float() {
         match (a.is_nan(), b.is_nan()) {
@@ -41,9 +42,11 @@ where
     }
 }
 
-fn compare_fn_nan_max<T>(a: &T, b: &T) -> Ordering
+#[inline]
+/// NaN will be larger than every valid value
+pub fn compare_fn_nan_max<T>(a: &T, b: &T) -> Ordering
 where
-    T: PartialOrd + IsFloat + NativeType,
+    T: PartialOrd + IsFloat,
 {
     if T::is_float() {
         match (a.is_nan(), b.is_nan()) {
