@@ -21,6 +21,8 @@ pub mod kernels;
 #[cfg(feature = "ndarray")]
 mod ndarray;
 
+#[cfg(feature = "dtype-binary")]
+pub mod binary;
 mod bitwise;
 #[cfg(feature = "object")]
 mod drop;
@@ -50,8 +52,6 @@ use std::slice::Iter;
 use bitflags::bitflags;
 use polars_arrow::prelude::*;
 
-#[cfg(feature = "dtype-categorical")]
-use crate::chunked_array::categorical::RevMapping;
 use crate::series::IsSorted;
 use crate::utils::{first_non_null, last_non_null, CustomIterTools};
 
@@ -100,7 +100,7 @@ pub type ChunkIdIter<'a> = std::iter::Map<std::slice::Iter<'a, ArrayRef>, fn(&Ar
 ///
 /// ```rust
 /// # use polars_core::prelude::*;
-/// fn to_chunked_array(series: &Series) -> Result<&Int32Chunked>{
+/// fn to_chunked_array(series: &Series) -> PolarsResult<&Int32Chunked>{
 ///     series.i32()
 /// }
 ///
@@ -151,9 +151,6 @@ pub struct ChunkedArray<T: PolarsDataType> {
     pub(crate) field: Arc<Field>,
     pub(crate) chunks: Vec<ArrayRef>,
     phantom: PhantomData<T>,
-    /// TODO! remove this. Should be in the DataType
-    /// maps categorical u32 indexes to String values
-    pub(crate) categorical_map: Option<Arc<RevMapping>>,
     pub(crate) bit_settings: Settings,
     length: IdxSize,
 }
@@ -163,51 +160,47 @@ bitflags! {
     pub(crate) struct Settings: u8 {
     const SORTED_ASC = 0x01;
     const SORTED_DSC = 0x02;
-    const FAST_EXPLODE_LIST = 0x03;
+    const FAST_EXPLODE_LIST = 0x04;
 }}
 
 impl<T: PolarsDataType> ChunkedArray<T> {
-    pub(crate) fn is_sorted(&self) -> bool {
+    pub(crate) fn is_sorted_flag(&self) -> bool {
         self.bit_settings.contains(Settings::SORTED_ASC)
     }
 
-    pub(crate) fn is_sorted_reverse(&self) -> bool {
+    pub(crate) fn is_sorted_reverse_flag(&self) -> bool {
         self.bit_settings.contains(Settings::SORTED_DSC)
     }
 
-    /// Set the 'sorted' bit meta info.
-    pub fn set_sorted(&mut self, reverse: bool) {
-        if reverse {
-            // unset sorted
-            self.bit_settings.remove(Settings::SORTED_ASC);
-            // set reverse sorted
-            self.bit_settings.insert(Settings::SORTED_DSC)
-        } else {
-            // // unset reverse sorted
-            self.bit_settings.remove(Settings::SORTED_DSC);
-            // set sorted
-            self.bit_settings.insert(Settings::SORTED_ASC)
-        }
-    }
-
-    pub fn is_sorted2(&self) -> IsSorted {
-        if self.is_sorted() {
+    pub fn is_sorted_flag2(&self) -> IsSorted {
+        if self.is_sorted_flag() {
             IsSorted::Ascending
-        } else if self.is_sorted_reverse() {
+        } else if self.is_sorted_reverse_flag() {
             IsSorted::Descending
         } else {
             IsSorted::Not
         }
     }
 
-    pub fn set_sorted2(&mut self, sorted: IsSorted) {
+    /// Set the 'sorted' bit meta info.
+    pub fn set_sorted_flag(&mut self, sorted: IsSorted) {
         match sorted {
             IsSorted::Not => {
                 self.bit_settings
                     .remove(Settings::SORTED_ASC | Settings::SORTED_DSC);
             }
-            IsSorted::Ascending => self.set_sorted(false),
-            IsSorted::Descending => self.set_sorted(true),
+            IsSorted::Ascending => {
+                // // unset reverse sorted
+                self.bit_settings.remove(Settings::SORTED_DSC);
+                // set sorted
+                self.bit_settings.insert(Settings::SORTED_ASC)
+            }
+            IsSorted::Descending => {
+                // unset sorted
+                self.bit_settings.remove(Settings::SORTED_ASC);
+                // set reverse sorted
+                self.bit_settings.insert(Settings::SORTED_DSC)
+            }
         }
     }
 
@@ -283,7 +276,7 @@ impl<T: PolarsDataType> ChunkedArray<T> {
     }
 
     /// Series to ChunkedArray<T>
-    pub fn unpack_series_matching_type(&self, series: &Series) -> Result<&ChunkedArray<T>> {
+    pub fn unpack_series_matching_type(&self, series: &Series) -> PolarsResult<&ChunkedArray<T>> {
         if self.dtype() == series.dtype() {
             // Safety
             // dtype will be correct.
@@ -331,47 +324,18 @@ impl<T: PolarsDataType> ChunkedArray<T> {
         self.chunks.iter().map(|arr| arr.null_count()).sum()
     }
 
-    /// Append arrow array in place.
-    ///
-    /// ```rust
-    /// # use polars_core::prelude::*;
-    /// let mut array = Int32Chunked::new("array", &[1, 2]);
-    /// let array_2 = Int32Chunked::new("2nd", &[3]);
-    ///
-    /// array.append(&array_2);
-    /// assert_eq!(Vec::from(&array), [Some(1), Some(2), Some(3)])
-    /// ```
-    pub fn append_array(&mut self, other: ArrayRef) -> Result<()> {
-        if self.field.data_type() == other.data_type() {
-            let length = other.len() as IdxSize;
-            self.chunks.push(other);
-            self.length += length;
-            Ok(())
-        } else {
-            Err(PolarsError::SchemaMisMatch(
-                format!(
-                    "cannot append array of type {:?} in array of type {:?}",
-                    other.data_type(),
-                    self.dtype()
-                )
-                .into(),
-            ))
-        }
-    }
-
     /// Create a new ChunkedArray from self, where the chunks are replaced.
     fn copy_with_chunks(&self, chunks: Vec<ArrayRef>, keep_sorted: bool) -> Self {
         let mut out = ChunkedArray {
             field: self.field.clone(),
             chunks,
             phantom: PhantomData,
-            categorical_map: self.categorical_map.clone(),
             bit_settings: self.bit_settings,
             length: 0,
         };
         out.compute_len();
         if !keep_sorted {
-            out.set_sorted2(IsSorted::Not);
+            out.set_sorted_flag(IsSorted::Not);
         }
         out
     }
@@ -498,7 +462,7 @@ where
 
 pub(crate) trait AsSinglePtr {
     /// Rechunk and return a ptr to the start of the array
-    fn as_single_ptr(&mut self) -> Result<usize> {
+    fn as_single_ptr(&mut self) -> PolarsResult<usize> {
         Err(PolarsError::InvalidOperation(
             "operation as_single_ptr not supported for this dtype".into(),
         ))
@@ -509,7 +473,7 @@ impl<T> AsSinglePtr for ChunkedArray<T>
 where
     T: PolarsNumericType,
 {
-    fn as_single_ptr(&mut self) -> Result<usize> {
+    fn as_single_ptr(&mut self) -> PolarsResult<usize> {
         let mut ca = self.rechunk();
         mem::swap(&mut ca, self);
         let a = self.data_views().next().unwrap();
@@ -521,6 +485,8 @@ where
 impl AsSinglePtr for BooleanChunked {}
 impl AsSinglePtr for ListChunked {}
 impl AsSinglePtr for Utf8Chunked {}
+#[cfg(feature = "dtype-binary")]
+impl AsSinglePtr for BinaryChunked {}
 #[cfg(feature = "object")]
 impl<T: PolarsObject> AsSinglePtr for ObjectChunked<T> {}
 
@@ -529,7 +495,7 @@ where
     T: PolarsNumericType,
 {
     /// Contiguous slice
-    pub fn cont_slice(&self) -> Result<&[T::Native]> {
+    pub fn cont_slice(&self) -> PolarsResult<&[T::Native]> {
         if self.chunks.len() == 1 && self.chunks[0].null_count() == 0 {
             Ok(self.downcast_iter().next().map(|arr| arr.values()).unwrap())
         } else {
@@ -572,7 +538,6 @@ impl<T: PolarsDataType> Clone for ChunkedArray<T> {
             field: self.field.clone(),
             chunks: self.chunks.clone(),
             phantom: PhantomData,
-            categorical_map: self.categorical_map.clone(),
             bit_settings: self.bit_settings,
             length: self.length,
         }
@@ -601,6 +566,15 @@ impl ValueSize for Utf8Chunked {
     }
 }
 
+#[cfg(feature = "dtype-binary")]
+impl ValueSize for BinaryChunked {
+    fn get_values_size(&self) -> usize {
+        self.chunks
+            .iter()
+            .fold(0usize, |acc, arr| acc + arr.get_values_size())
+    }
+}
+
 impl ListChunked {
     /// Get the inner data type of the list.
     pub fn inner_dtype(&self) -> DataType {
@@ -621,7 +595,7 @@ pub(crate) fn to_primitive<T: PolarsNumericType>(
     values: Vec<T::Native>,
     validity: Option<Bitmap>,
 ) -> PrimitiveArray<T::Native> {
-    PrimitiveArray::from_data(T::get_dtype().to_arrow(), values.into(), validity)
+    PrimitiveArray::new(T::get_dtype().to_arrow(), values.into(), validity)
 }
 
 pub(crate) fn to_array<T: PolarsNumericType>(
@@ -658,17 +632,20 @@ pub(crate) mod test {
         let a = a.sort(false);
         let b = a.into_iter().collect::<Vec<_>>();
         assert_eq!(b, [Some("a"), Some("b"), Some("c")]);
+        assert_eq!(a.is_sorted_flag(), true);
     }
 
     #[test]
     fn arithmetic() {
-        let s1 = get_chunked_array();
-        println!("{:?}", s1.chunks);
-        let s2 = &s1;
-        let s1 = &s1;
-        println!("{:?}", s1 + s2);
-        println!("{:?}", s1 - s2);
-        println!("{:?}", s1 * s2);
+        let a = &Int32Chunked::new("a", &[1, 100, 6, 40]);
+        let b = &Int32Chunked::new("b", &[-1, 2, 3, 4]);
+
+        // Not really asserting anything here but shill making sure the code is exercised
+        // This (and more) is properly tested from the integration test suite and Python bindings.
+        println!("{:?}", a + b);
+        println!("{:?}", a - b);
+        println!("{:?}", a * b);
+        println!("{:?}", a / b);
     }
 
     #[test]
@@ -697,11 +674,11 @@ pub(crate) mod test {
     }
 
     #[test]
-    fn aggregates_numeric() {
-        let a = get_chunked_array();
-        assert_eq!(a.max(), Some(3));
+    fn aggregates() {
+        let a = &Int32Chunked::new("a", &[1, 100, 10, 9]);
+        assert_eq!(a.max(), Some(100));
         assert_eq!(a.min(), Some(1));
-        assert_eq!(a.sum(), Some(6))
+        assert_eq!(a.sum(), Some(120))
     }
 
     #[test]
@@ -711,15 +688,6 @@ pub(crate) mod test {
         assert_eq!(new.len(), 2)
     }
 
-    #[test]
-    fn get() {
-        let mut a = get_chunked_array();
-        assert_eq!(AnyValue::Int32(2), a.get_any_value(1));
-        // check if chunks indexes are properly determined
-        a.append_array(a.chunks[0].clone()).unwrap();
-        assert_eq!(AnyValue::Int32(1), a.get_any_value(3));
-    }
-
     #[test]
     fn cast() {
         let a = get_chunked_array();
