@@ -12,6 +12,8 @@ use polars_extension::PolarsExtension;
 use crate::prelude::*;
 use crate::PROCESS_ID;
 
+pub const EXTENSION_NAME: &str = "POLARS_EXTENSION_TYPE";
+
 /// Invariants
 /// `ptr` must point to start a `T` allocation
 /// `n_t_vals` must represent the correct number of `T` values in that allocation
@@ -56,10 +58,7 @@ pub(crate) fn create_extension<
 ) -> PolarsExtension {
     let env = "POLARS_ALLOW_EXTENSION";
     std::env::var(env).unwrap_or_else(|_| {
-        panic!(
-            "env var: {} must be set to allow extension types to be created",
-            env
-        )
+        panic!("env var: {env} must be set to allow extension types to be created",)
     });
     let t_size = std::mem::size_of::<T>();
     let t_alignment = std::mem::align_of::<T>();
@@ -118,11 +117,8 @@ pub(crate) fn create_extension<
     let metadata = format!("{};{}", *PROCESS_ID, et_ptr as usize);
 
     let physical_type = ArrowDataType::FixedSizeBinary(t_size);
-    let extension_type = ArrowDataType::Extension(
-        "POLARS_EXTENSION_TYPE".into(),
-        physical_type.into(),
-        Some(metadata),
-    );
+    let extension_type =
+        ArrowDataType::Extension(EXTENSION_NAME.into(), physical_type.into(), Some(metadata));
     // first freeze, otherwise we compute null
     let validity = if null_count > 0 {
         Some(validity.into())
@@ -130,7 +126,7 @@ pub(crate) fn create_extension<
         None
     };
 
-    let array = FixedSizeBinaryArray::from_data(extension_type, buf, validity);
+    let array = FixedSizeBinaryArray::new(extension_type, buf, validity);
 
     // Safety:
     // we just heap allocated the ExtensionSentinel, so its alive.
