@@ -7,6 +7,7 @@ use polars_arrow::array::PolarsArray;
 use polars_arrow::trusted_len::PushUnchecked;
 
 use crate::prelude::*;
+use crate::series::IsSorted;
 use crate::utils::{CustomIterTools, NoNull};
 
 macro_rules! try_apply {
@@ -118,6 +119,8 @@ impl<T: PolarsNumericType> ChunkedArray<T> {
             self.downcast_iter_mut()
                 .for_each(|arr| arrow::compute::arity_assign::unary(arr, f))
         };
+        // can be in any order now
+        self.set_sorted_flag(IsSorted::Not);
     }
 }
 
@@ -179,19 +182,19 @@ where
         ChunkedArray::<T>::from_chunks(self.name(), chunks)
     }
 
-    fn try_apply<F>(&'a self, f: F) -> Result<Self>
+    fn try_apply<F>(&'a self, f: F) -> PolarsResult<Self>
     where
-        F: Fn(T::Native) -> Result<T::Native> + Copy,
+        F: Fn(T::Native) -> PolarsResult<T::Native> + Copy,
     {
         let mut ca: ChunkedArray<T> = self
             .data_views()
             .into_iter()
             .zip(self.iter_validities())
             .map(|(slice, validity)| {
-                let vec: Result<Vec<_>> = slice.iter().copied().map(f).collect();
+                let vec: PolarsResult<Vec<_>> = slice.iter().copied().map(f).collect();
                 Ok((vec?, validity.cloned()))
             })
-            .collect::<Result<_>>()?;
+            .collect::<PolarsResult<_>>()?;
         ca.rename(self.name());
         Ok(ca)
     }
@@ -303,9 +306,9 @@ impl<'a> ChunkApply<'a, bool, bool> for BooleanChunked {
         apply!(self, f)
     }
 
-    fn try_apply<F>(&self, f: F) -> Result<Self>
+    fn try_apply<F>(&self, f: F) -> PolarsResult<Self>
     where
-        F: Fn(bool) -> Result<bool> + Copy,
+        F: Fn(bool) -> PolarsResult<bool> + Copy,
     {
         try_apply!(self, f)
     }
@@ -392,9 +395,9 @@ impl<'a> ChunkApply<'a, &'a str, Cow<'a, str>> for Utf8Chunked {
         apply!(self, f)
     }
 
-    fn try_apply<F>(&'a self, f: F) -> Result<Self>
+    fn try_apply<F>(&'a self, f: F) -> PolarsResult<Self>
     where
-        F: Fn(&'a str) -> Result<Cow<'a, str>> + Copy,
+        F: Fn(&'a str) -> PolarsResult<Cow<'a, str>> + Copy,
     {
         try_apply!(self, f)
     }
@@ -443,6 +446,100 @@ impl<'a> ChunkApply<'a, &'a str, Cow<'a, str>> for Utf8Chunked {
     }
 }
 
+#[cfg(feature = "dtype-binary")]
+impl<'a> ChunkApply<'a, &'a [u8], Cow<'a, [u8]>> for BinaryChunked {
+    fn apply_cast_numeric<F, S>(&'a self, f: F) -> ChunkedArray<S>
+    where
+        F: Fn(&'a [u8]) -> S::Native + Copy,
+        S: PolarsNumericType,
+    {
+        let chunks = self
+            .downcast_iter()
+            .into_iter()
+            .map(|array| {
+                let values = array.values_iter().map(f);
+                let values = Vec::<_>::from_trusted_len_iter(values);
+                to_array::<S>(values, array.validity().cloned())
+            })
+            .collect();
+        ChunkedArray::from_chunks(self.name(), chunks)
+    }
+
+    fn branch_apply_cast_numeric_no_null<F, S>(&'a self, f: F) -> ChunkedArray<S>
+    where
+        F: Fn(Option<&'a [u8]>) -> S::Native + Copy,
+        S: PolarsNumericType,
+    {
+        let chunks = self
+            .downcast_iter()
+            .into_iter()
+            .map(|array| {
+                let values = array.into_iter().map(f);
+                let values = Vec::<_>::from_trusted_len_iter(values);
+                to_array::<S>(values, array.validity().cloned())
+            })
+            .collect();
+        ChunkedArray::from_chunks(self.name(), chunks)
+    }
+
+    fn apply<F>(&'a self, f: F) -> Self
+    where
+        F: Fn(&'a [u8]) -> Cow<'a, [u8]> + Copy,
+    {
+        apply!(self, f)
+    }
+
+    fn try_apply<F>(&'a self, f: F) -> PolarsResult<Self>
+    where
+        F: Fn(&'a [u8]) -> PolarsResult<Cow<'a, [u8]>> + Copy,
+    {
+        try_apply!(self, f)
+    }
+
+    fn apply_on_opt<F>(&'a self, f: F) -> Self
+    where
+        F: Fn(Option<&'a [u8]>) -> Option<Cow<'a, [u8]>> + Copy,
+    {
+        let mut ca: Self = self.into_iter().map(f).collect_trusted();
+        ca.rename(self.name());
+        ca
+    }
+
+    fn apply_with_idx<F>(&'a self, f: F) -> Self
+    where
+        F: Fn((usize, &'a [u8])) -> Cow<'a, [u8]> + Copy,
+    {
+        apply_enumerate!(self, f)
+    }
+
+    fn apply_with_idx_on_opt<F>(&'a self, f: F) -> Self
+    where
+        F: Fn((usize, Option<&'a [u8]>)) -> Option<Cow<'a, [u8]>> + Copy,
+    {
+        let mut ca: Self = self.into_iter().enumerate().map(f).collect_trusted();
+        ca.rename(self.name());
+        ca
+    }
+
+    fn apply_to_slice<F, T>(&'a self, f: F, slice: &mut [T])
+    where
+        F: Fn(Option<&'a [u8]>, &T) -> T,
+    {
+        assert!(slice.len() >= self.len());
+
+        let mut idx = 0;
+        self.downcast_iter().for_each(|arr| {
+            arr.into_iter().for_each(|opt_val| {
+                // Safety:
+                // length asserted above
+                let item = unsafe { slice.get_unchecked_mut(idx) };
+                *item = f(opt_val, item);
+                idx += 1;
+            })
+        });
+    }
+}
+
 impl ChunkApplyKernel<BooleanArray> for BooleanChunked {
     fn apply_kernel(&self, f: &dyn Fn(&BooleanArray) -> ArrayRef) -> Self {
         let chunks = self.downcast_iter().into_iter().map(f).collect();
@@ -491,6 +588,21 @@ impl ChunkApplyKernel<LargeStringArray> for Utf8Chunked {
     }
 }
 
+#[cfg(feature = "dtype-binary")]
+impl ChunkApplyKernel<LargeBinaryArray> for BinaryChunked {
+    fn apply_kernel(&self, f: &dyn Fn(&LargeBinaryArray) -> ArrayRef) -> Self {
+        self.apply_kernel_cast(&f)
+    }
+
+    fn apply_kernel_cast<S>(&self, f: &dyn Fn(&LargeBinaryArray) -> ArrayRef) -> ChunkedArray<S>
+    where
+        S: PolarsDataType,
+    {
+        let chunks = self.downcast_iter().into_iter().map(f).collect();
+        ChunkedArray::from_chunks(self.name(), chunks)
+    }
+}
+
 impl<'a> ChunkApply<'a, Series, Series> for ListChunked {
     fn apply_cast_numeric<F, S>(&self, f: F) -> ChunkedArray<S>
     where
@@ -540,7 +652,7 @@ impl<'a> ChunkApply<'a, Series, Series> for ListChunked {
                     });
                     f(x)
                 });
-                let len = values.len();
+                let len = array.len();
 
                 // we know the iterators len
                 unsafe {
@@ -575,9 +687,9 @@ impl<'a> ChunkApply<'a, Series, Series> for ListChunked {
         ca
     }
 
-    fn try_apply<F>(&'a self, f: F) -> Result<Self>
+    fn try_apply<F>(&'a self, f: F) -> PolarsResult<Self>
     where
-        F: Fn(Series) -> Result<Series> + Copy,
+        F: Fn(Series) -> PolarsResult<Series> + Copy,
     {
         if self.is_empty() {
             return Ok(self.clone());
@@ -593,7 +705,7 @@ impl<'a> ChunkApply<'a, Series, Series> for ListChunked {
             }
             out
         };
-        let ca: Result<ListChunked> = try_apply!(self, &mut function);
+        let ca: PolarsResult<ListChunked> = try_apply!(self, &mut function);
         let mut ca = ca?;
         if fast_explode {
             ca.set_fast_explode()
@@ -710,9 +822,9 @@ where
         ca
     }
 
-    fn try_apply<F>(&'a self, _f: F) -> Result<Self>
+    fn try_apply<F>(&'a self, _f: F) -> PolarsResult<Self>
     where
-        F: Fn(&'a T) -> Result<T> + Copy,
+        F: Fn(&'a T) -> PolarsResult<T> + Copy,
     {
         todo!()
     }
