@@ -1,6 +1,7 @@
-use crate::prelude::*;
 use num::{abs, clamp};
 
+use crate::prelude::*;
+
 macro_rules! impl_shift_fill {
     ($self:ident, $periods:expr, $fill_value:expr) => {{
         let periods = clamp($periods, -($self.len() as i64), $self.len() as i64);
@@ -59,18 +60,32 @@ impl ChunkShiftFill<Utf8Type, Option<&str>> for Utf8Chunked {
     }
 }
 
+#[cfg(feature = "dtype-binary")]
+impl ChunkShiftFill<BinaryType, Option<&[u8]>> for BinaryChunked {
+    fn shift_and_fill(&self, periods: i64, fill_value: Option<&[u8]>) -> BinaryChunked {
+        impl_shift_fill!(self, periods, fill_value)
+    }
+}
+
 impl ChunkShift<Utf8Type> for Utf8Chunked {
     fn shift(&self, periods: i64) -> Self {
         self.shift_and_fill(periods, None)
     }
 }
 
+#[cfg(feature = "dtype-binary")]
+impl ChunkShift<BinaryType> for BinaryChunked {
+    fn shift(&self, periods: i64) -> Self {
+        self.shift_and_fill(periods, None)
+    }
+}
+
 impl ChunkShiftFill<ListType, Option<&Series>> for ListChunked {
     fn shift_and_fill(&self, periods: i64, fill_value: Option<&Series>) -> ListChunked {
         // This has its own implementation because a ListChunked cannot have a full-null without
         // knowing the inner type
         let periods = clamp(periods, -(self.len() as i64), self.len() as i64);
-        let slice_offset = (-periods).max(0) as i64;
+        let slice_offset = (-periods).max(0);
         let length = self.len() - abs(periods) as usize;
         let mut slice = self.slice(slice_offset, length);
 
@@ -83,10 +98,10 @@ impl ChunkShiftFill<ListType, Option<&Series>> for ListChunked {
         };
 
         if periods < 0 {
-            slice.append(&fill);
+            slice.append(&fill).unwrap();
             slice
         } else {
-            fill.append(&slice);
+            fill.append(&slice).unwrap();
             fill
         }
     }
