@@ -10,7 +10,7 @@ use rayon::prelude::*;
 use super::*;
 use crate::frame::groupby::hashing::HASHMAP_INIT_SIZE;
 #[cfg(feature = "dtype-categorical")]
-use crate::frame::hash_join::check_categorical_src;
+use crate::frame::hash_join::_check_categorical_src;
 use crate::frame::hash_join::{
     create_probe_table, get_hash_tbl_threaded_join_partitioned, multiple_keys as mk, prepare_strs,
 };
@@ -155,6 +155,7 @@ fn process_group<K, T>(
     left_asof: &[T],
     right_asof: &[T],
     results: &mut Vec<Option<IdxSize>>,
+    forward: bool,
 ) where
     K: Hash + PartialEq + Eq,
     T: NativeType + Sub<Output = T> + PartialOrd + num::Zero,
@@ -175,6 +176,9 @@ fn process_group<K, T>(
             right_tbl_offsets.insert(k, (offset_slice, join_idx));
         }
         None => {
+            if forward {
+                previous_join_idx = None;
+            }
             if tolerance > num::zero() {
                 if let Some(idx) = previous_join_idx {
                     debug_assert!((idx as usize) < right_asof.len());
@@ -204,20 +208,31 @@ where
     S::Native: Hash + Eq + AsU64,
 {
     #[allow(clippy::type_complexity)]
-    let (join_asof_fn, tolerance): (
+    let (join_asof_fn, tolerance, forward): (
         unsafe fn(T::Native, &[T::Native], &[IdxSize], T::Native) -> (Option<IdxSize>, usize),
         _,
+        _,
     ) = match (tolerance, strategy) {
         (Some(tolerance), AsofStrategy::Backward) => {
             let tol = tolerance.extract::<T::Native>().unwrap();
-            (join_asof_backward_with_indirection_and_tolerance, tol)
+            (
+                join_asof_backward_with_indirection_and_tolerance,
+                tol,
+                false,
+            )
         }
-        (None, AsofStrategy::Backward) => (join_asof_backward_with_indirection, T::Native::zero()),
+        (None, AsofStrategy::Backward) => (
+            join_asof_backward_with_indirection,
+            T::Native::zero(),
+            false,
+        ),
         (Some(tolerance), AsofStrategy::Forward) => {
             let tol = tolerance.extract::<T::Native>().unwrap();
-            (join_asof_forward_with_indirection_and_tolerance, tol)
+            (join_asof_forward_with_indirection_and_tolerance, tol, true)
+        }
+        (None, AsofStrategy::Forward) => {
+            (join_asof_forward_with_indirection, T::Native::zero(), true)
         }
-        (None, AsofStrategy::Forward) => (join_asof_forward_with_indirection, T::Native::zero()),
     };
 
     let left_asof = left_asof.rechunk();
@@ -297,6 +312,7 @@ where
                                 left_asof,
                                 right_asof,
                                 &mut results,
+                                forward,
                             );
                         }
                         // only left values, right = null
@@ -322,20 +338,31 @@ where
     T: PolarsNumericType,
 {
     #[allow(clippy::type_complexity)]
-    let (join_asof_fn, tolerance): (
+    let (join_asof_fn, tolerance, forward): (
         unsafe fn(T::Native, &[T::Native], &[IdxSize], T::Native) -> (Option<IdxSize>, usize),
         _,
+        _,
     ) = match (tolerance, strategy) {
         (Some(tolerance), AsofStrategy::Backward) => {
             let tol = tolerance.extract::<T::Native>().unwrap();
-            (join_asof_backward_with_indirection_and_tolerance, tol)
+            (
+                join_asof_backward_with_indirection_and_tolerance,
+                tol,
+                false,
+            )
         }
-        (None, AsofStrategy::Backward) => (join_asof_backward_with_indirection, T::Native::zero()),
+        (None, AsofStrategy::Backward) => (
+            join_asof_backward_with_indirection,
+            T::Native::zero(),
+            false,
+        ),
         (Some(tolerance), AsofStrategy::Forward) => {
             let tol = tolerance.extract::<T::Native>().unwrap();
-            (join_asof_forward_with_indirection_and_tolerance, tol)
+            (join_asof_forward_with_indirection_and_tolerance, tol, true)
+        }
+        (None, AsofStrategy::Forward) => {
+            (join_asof_forward_with_indirection, T::Native::zero(), true)
         }
-        (None, AsofStrategy::Forward) => (join_asof_forward_with_indirection, T::Native::zero()),
     };
 
     let left_asof = left_asof.rechunk();
@@ -345,11 +372,11 @@ where
     let right_asof = right_asof.cont_slice().unwrap();
 
     let n_threads = POOL.current_num_threads();
-    let splitted_left = split_ca(by_left, n_threads).unwrap();
+    let splitted_by_left = split_ca(by_left, n_threads).unwrap();
     let splitted_right = split_ca(by_right, n_threads).unwrap();
 
     let hb = RandomState::default();
-    let vals_left = prepare_strs(&splitted_left, &hb);
+    let vals_left = prepare_strs(&splitted_by_left, &hb);
     let vals_right = prepare_strs(&splitted_right, &hb);
 
     let hash_tbls = create_probe_table(vals_right);
@@ -407,6 +434,7 @@ where
                                 left_asof,
                                 right_asof,
                                 &mut results,
+                                forward,
                             );
                         }
                         // only left values, right = null
@@ -434,20 +462,31 @@ where
     T: PolarsNumericType,
 {
     #[allow(clippy::type_complexity)]
-    let (join_asof_fn, tolerance): (
+    let (join_asof_fn, tolerance, forward): (
         unsafe fn(T::Native, &[T::Native], &[IdxSize], T::Native) -> (Option<IdxSize>, usize),
         _,
+        _,
     ) = match (tolerance, strategy) {
         (Some(tolerance), AsofStrategy::Backward) => {
             let tol = tolerance.extract::<T::Native>().unwrap();
-            (join_asof_backward_with_indirection_and_tolerance, tol)
+            (
+                join_asof_backward_with_indirection_and_tolerance,
+                tol,
+                false,
+            )
         }
-        (None, AsofStrategy::Backward) => (join_asof_backward_with_indirection, T::Native::zero()),
+        (None, AsofStrategy::Backward) => (
+            join_asof_backward_with_indirection,
+            T::Native::zero(),
+            false,
+        ),
         (Some(tolerance), AsofStrategy::Forward) => {
             let tol = tolerance.extract::<T::Native>().unwrap();
-            (join_asof_forward_with_indirection_and_tolerance, tol)
+            (join_asof_forward_with_indirection_and_tolerance, tol, true)
+        }
+        (None, AsofStrategy::Forward) => {
+            (join_asof_forward_with_indirection, T::Native::zero(), true)
         }
-        (None, AsofStrategy::Forward) => (join_asof_forward_with_indirection, T::Native::zero()),
     };
     let left_asof = left_asof.rechunk();
     let left_asof = left_asof.cont_slice().unwrap();
@@ -515,6 +554,7 @@ where
                                     left_asof,
                                     right_asof,
                                     &mut results,
+                                    forward,
                                 );
                             }
                             // only left values, right = null
@@ -531,131 +571,99 @@ where
     })
 }
 
+#[allow(clippy::too_many_arguments)]
+fn dispatch_join<T: PolarsNumericType>(
+    left_asof: &ChunkedArray<T>,
+    right_asof: &ChunkedArray<T>,
+    left_by_s: &Series,
+    right_by_s: &Series,
+    left_by: &mut DataFrame,
+    right_by: &mut DataFrame,
+    strategy: AsofStrategy,
+    tolerance: Option<AnyValue<'static>>,
+) -> PolarsResult<Vec<Option<IdxSize>>> {
+    let out = if left_by.width() == 1 {
+        match left_by_s.dtype() {
+            DataType::Utf8 => asof_join_by_utf8(
+                left_by_s.utf8().unwrap(),
+                right_by_s.utf8().unwrap(),
+                left_asof,
+                right_asof,
+                tolerance,
+                strategy,
+            ),
+            _ => {
+                if left_by_s.bit_repr_is_large() {
+                    let left_by = left_by_s.bit_repr_large();
+                    let right_by = right_by_s.bit_repr_large();
+                    asof_join_by_numeric(
+                        &left_by, &right_by, left_asof, right_asof, tolerance, strategy,
+                    )?
+                } else {
+                    let left_by = left_by_s.bit_repr_small();
+                    let right_by = right_by_s.bit_repr_small();
+                    asof_join_by_numeric(
+                        &left_by, &right_by, left_asof, right_asof, tolerance, strategy,
+                    )?
+                }
+            }
+        }
+    } else {
+        for (lhs, rhs) in left_by.get_columns().iter().zip(right_by.get_columns()) {
+            check_asof_columns(lhs, rhs)?;
+            #[cfg(feature = "dtype-categorical")]
+            _check_categorical_src(lhs.dtype(), rhs.dtype())?;
+        }
+        asof_join_by_multiple(
+            left_by, right_by, left_asof, right_asof, tolerance, strategy,
+        )
+    };
+    Ok(out)
+}
+
 impl DataFrame {
     #[cfg_attr(docsrs, doc(cfg(feature = "asof_join")))]
     #[allow(clippy::too_many_arguments)]
     #[doc(hidden)]
-    pub fn _join_asof_by<I, S>(
+    pub fn _join_asof_by(
         &self,
         other: &DataFrame,
         left_on: &str,
         right_on: &str,
-        left_by: I,
-        right_by: I,
+        left_by: Vec<String>,
+        right_by: Vec<String>,
         strategy: AsofStrategy,
         tolerance: Option<AnyValue<'static>>,
         slice: Option<(i64, usize)>,
-    ) -> PolarsResult<DataFrame>
-    where
-        I: IntoIterator<Item = S>,
-        S: AsRef<str>,
-    {
-        use DataType::*;
-        let left_asof = self.column(left_on)?;
-        let right_asof = other.column(right_on)?;
+    ) -> PolarsResult<DataFrame> {
+        let left_asof = self.column(left_on)?.to_physical_repr();
+        let right_asof = other.column(right_on)?.to_physical_repr();
         let right_asof_name = right_asof.name();
         let left_asof_name = left_asof.name();
 
-        check_asof_columns(left_asof, right_asof)?;
+        check_asof_columns(&left_asof, &right_asof)?;
 
-        let mut left_by = self.select(left_by)?;
-        let mut right_by = other.select(right_by)?;
+        let mut left_by = self.select_physical(left_by)?;
+        let mut right_by = other.select_physical(right_by)?;
 
-        let left_by_s = &left_by.get_columns()[0];
-        let right_by_s = &right_by.get_columns()[0];
+        let left_by_s = left_by.get_columns()[0].to_physical_repr().into_owned();
+        let right_by_s = right_by.get_columns()[0].to_physical_repr().into_owned();
 
-        let right_join_tuples = if left_asof.bit_repr_is_large() {
-            // we cannot use bit repr as that loses ordering
-            let left_asof = left_asof.cast(&DataType::Int64)?;
-            let right_asof = right_asof.cast(&DataType::Int64)?;
-            let left_asof = left_asof.i64().unwrap();
-            let right_asof = right_asof.i64().unwrap();
+        let right_join_tuples = with_match_physical_numeric_polars_type!(left_asof.dtype(), |$T| {
+            let left_asof: &ChunkedArray<$T> = left_asof.as_ref().as_ref().as_ref();
+            let right_asof: &ChunkedArray<$T> = right_asof.as_ref().as_ref().as_ref();
 
-            if left_by.width() == 1 {
-                match left_by_s.dtype() {
-                    Utf8 => asof_join_by_utf8(
-                        left_by_s.utf8().unwrap(),
-                        right_by_s.utf8().unwrap(),
-                        left_asof,
-                        right_asof,
-                        tolerance,
-                        strategy,
-                    ),
-                    _ => {
-                        if left_by_s.bit_repr_is_large() {
-                            let left_by = left_by_s.bit_repr_large();
-                            let right_by = right_by_s.bit_repr_large();
-                            asof_join_by_numeric(
-                                &left_by, &right_by, left_asof, right_asof, tolerance, strategy,
-                            )?
-                        } else {
-                            let left_by = left_by_s.bit_repr_small();
-                            let right_by = right_by_s.bit_repr_small();
-                            asof_join_by_numeric(
-                                &left_by, &right_by, left_asof, right_asof, tolerance, strategy,
-                            )?
-                        }
-                    }
-                }
-            } else {
-                for (lhs, rhs) in left_by.get_columns().iter().zip(right_by.get_columns()) {
-                    check_asof_columns(lhs, rhs)?;
-                    #[cfg(feature = "dtype-categorical")]
-                    check_categorical_src(lhs.dtype(), rhs.dtype())?;
-                }
-                asof_join_by_multiple(
-                    &mut left_by,
-                    &mut right_by,
-                    left_asof,
-                    right_asof,
-                    tolerance,
-                    strategy,
-                )
-            }
-        } else {
-            // we cannot use bit repr as that loses ordering
-            let left_asof = left_asof.cast(&DataType::Int32)?;
-            let right_asof = right_asof.cast(&DataType::Int32)?;
-            let left_asof = left_asof.i32().unwrap();
-            let right_asof = right_asof.i32().unwrap();
-
-            if left_by.width() == 1 {
-                match left_by_s.dtype() {
-                    Utf8 => asof_join_by_utf8(
-                        left_by_s.utf8().unwrap(),
-                        right_by_s.utf8().unwrap(),
-                        left_asof,
-                        right_asof,
-                        tolerance,
-                        strategy,
-                    ),
-                    _ => {
-                        if left_by_s.bit_repr_is_large() {
-                            let left_by = left_by_s.bit_repr_large();
-                            let right_by = right_by_s.bit_repr_large();
-                            asof_join_by_numeric(
-                                &left_by, &right_by, left_asof, right_asof, tolerance, strategy,
-                            )?
-                        } else {
-                            let left_by = left_by_s.bit_repr_small();
-                            let right_by = right_by_s.bit_repr_small();
-                            asof_join_by_numeric(
-                                &left_by, &right_by, left_asof, right_asof, tolerance, strategy,
-                            )?
-                        }
-                    }
-                }
-            } else {
-                asof_join_by_multiple(
-                    &mut left_by,
-                    &mut right_by,
-                    left_asof,
-                    right_asof,
-                    tolerance,
-                    strategy,
-                )
-            }
-        };
+            dispatch_join(
+                left_asof,
+                right_asof,
+                &left_by_s,
+                &right_by_s,
+                &mut left_by,
+                &mut right_by,
+                strategy,
+                tolerance
+            )
+        })?;
 
         let mut drop_these = right_by.get_column_names();
         if left_asof_name == right_asof_name {
@@ -715,6 +723,14 @@ impl DataFrame {
         I: IntoIterator<Item = S>,
         S: AsRef<str>,
     {
+        let left_by = left_by
+            .into_iter()
+            .map(|s| s.as_ref().to_string())
+            .collect();
+        let right_by = right_by
+            .into_iter()
+            .map(|s| s.as_ref().to_string())
+            .collect();
         self._join_asof_by(
             other, left_on, right_on, left_by, right_by, strategy, tolerance, None,
         )
@@ -872,13 +888,9 @@ mod test {
         │ i64  ┆ str    ┆ i32            ┆ f64    │
         ╞══════╪════════╪════════════════╪════════╡
         │ 23   ┆ MSFT   ┆ 1              ┆ 51.95  │
-        ├╌╌╌╌╌╌┼╌╌╌╌╌╌╌╌┼╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌┼╌╌╌╌╌╌╌╌┤
         │ 38   ┆ MSFT   ┆ 1              ┆ 51.95  │
-        ├╌╌╌╌╌╌┼╌╌╌╌╌╌╌╌┼╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌┼╌╌╌╌╌╌╌╌┤
         │ 48   ┆ GOOG   ┆ 2              ┆ 720.77 │
-        ├╌╌╌╌╌╌┼╌╌╌╌╌╌╌╌┼╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌┼╌╌╌╌╌╌╌╌┤
         │ 48   ┆ GOOG   ┆ 2              ┆ 720.92 │
-        ├╌╌╌╌╌╌┼╌╌╌╌╌╌╌╌┼╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌┼╌╌╌╌╌╌╌╌┤
         │ 48   ┆ AAPL   ┆ 3              ┆ 98.0   │
         └──────┴────────┴────────────────┴────────┘
         quotes:
@@ -889,19 +901,12 @@ mod test {
         │ i64  ┆ str    ┆ f64   ┆ i32            │
         ╞══════╪════════╪═══════╪════════════════╡
         │ 23   ┆ GOOG   ┆ 720.5 ┆ 2              │
-        ├╌╌╌╌╌╌┼╌╌╌╌╌╌╌╌┼╌╌╌╌╌╌╌┼╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌┤
         │ 23   ┆ MSFT   ┆ 51.95 ┆ 1              │
-        ├╌╌╌╌╌╌┼╌╌╌╌╌╌╌╌┼╌╌╌╌╌╌╌┼╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌┤
         │ 30   ┆ MSFT   ┆ 51.97 ┆ 1              │
-        ├╌╌╌╌╌╌┼╌╌╌╌╌╌╌╌┼╌╌╌╌╌╌╌┼╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌┤
         │ 41   ┆ MSFT   ┆ 51.99 ┆ 1              │
-        ├╌╌╌╌╌╌┼╌╌╌╌╌╌╌╌┼╌╌╌╌╌╌╌┼╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌┤
         │ 48   ┆ GOOG   ┆ 720.5 ┆ 2              │
-        ├╌╌╌╌╌╌┼╌╌╌╌╌╌╌╌┼╌╌╌╌╌╌╌┼╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌┤
         │ 49   ┆ AAPL   ┆ 97.99 ┆ 3              │
-        ├╌╌╌╌╌╌┼╌╌╌╌╌╌╌╌┼╌╌╌╌╌╌╌┼╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌┤
         │ 72   ┆ GOOG   ┆ 720.5 ┆ 2              │
-        ├╌╌╌╌╌╌┼╌╌╌╌╌╌╌╌┼╌╌╌╌╌╌╌┼╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌┤
         │ 75   ┆ MSFT   ┆ 52.01 ┆ 1              │
         └──────┴────────┴───────┴────────────────┘
         */
