@@ -1,3 +1,5 @@
+use arrow::offset::Offsets;
+
 use super::*;
 #[cfg(feature = "dtype-struct")]
 use crate::chunked_array::builder::AnonymousOwnedListBuilder;
@@ -67,16 +69,19 @@ where
                     None
                 };
 
-                let array = PrimitiveArray::from_data(
-                    T::get_dtype().to_arrow(),
-                    list_values.into(),
-                    validity,
-                );
+                let array =
+                    PrimitiveArray::new(T::get_dtype().to_arrow(), list_values.into(), validity);
                 let data_type = ListArray::<i64>::default_datatype(T::get_dtype().to_arrow());
-                let arr =
-                    ListArray::<i64>::from_data(data_type, offsets.into(), Arc::new(array), None);
+                // Safety:
+                // offsets are monotonically increasing
+                let arr = ListArray::<i64>::new(
+                    data_type,
+                    Offsets::new_unchecked(offsets).into(),
+                    Box::new(array),
+                    None,
+                );
 
-                let mut ca = ListChunked::from_chunks(self.name(), vec![Arc::new(arr)]);
+                let mut ca = ListChunked::from_chunks(self.name(), vec![Box::new(arr)]);
                 if can_fast_explode {
                     ca.set_fast_explode()
                 }
@@ -124,15 +129,16 @@ where
                     None
                 };
 
-                let array = PrimitiveArray::from_data(
-                    T::get_dtype().to_arrow(),
-                    list_values.into(),
-                    validity,
-                );
+                let array =
+                    PrimitiveArray::new(T::get_dtype().to_arrow(), list_values.into(), validity);
                 let data_type = ListArray::<i64>::default_datatype(T::get_dtype().to_arrow());
-                let arr =
-                    ListArray::<i64>::from_data(data_type, offsets.into(), Arc::new(array), None);
-                let mut ca = ListChunked::from_chunks(self.name(), vec![Arc::new(arr)]);
+                let arr = ListArray::<i64>::new(
+                    data_type,
+                    Offsets::new_unchecked(offsets).into(),
+                    Box::new(array),
+                    None,
+                );
+                let mut ca = ListChunked::from_chunks(self.name(), vec![Box::new(arr)]);
                 if can_fast_explode {
                     ca.set_fast_explode()
                 }
@@ -192,6 +198,32 @@ impl AggList for Utf8Chunked {
     }
 }
 
+#[cfg(feature = "dtype-binary")]
+impl AggList for BinaryChunked {
+    unsafe fn agg_list(&self, groups: &GroupsProxy) -> Series {
+        match groups {
+            GroupsProxy::Idx(groups) => {
+                let mut builder =
+                    ListBinaryChunkedBuilder::new(self.name(), groups.len(), self.len());
+                for idx in groups.all().iter() {
+                    let ca = { self.take_unchecked(idx.into()) };
+                    builder.append(&ca)
+                }
+                builder.finish().into_series()
+            }
+            GroupsProxy::Slice { groups, .. } => {
+                let mut builder =
+                    ListBinaryChunkedBuilder::new(self.name(), groups.len(), self.len());
+                for [first, len] in groups {
+                    let ca = self.slice(*first as i64, *len as usize);
+                    builder.append(&ca)
+                }
+                builder.finish().into_series()
+            }
+        }
+    }
+}
+
 fn agg_list_list<F: Fn(&ListChunked, bool, &mut Vec<i64>, &mut i64, &mut Vec<ArrayRef>) -> bool>(
     ca: &ListChunked,
     groups_len: usize,
@@ -212,19 +244,21 @@ fn agg_list_list<F: Fn(&ListChunked, bool, &mut Vec<i64>, &mut i64, &mut Vec<Arr
         &mut list_values,
     );
     if groups_len == 0 {
-        list_values.push(ca.chunks[0].slice(0, 0).into())
+        list_values.push(ca.chunks[0].slice(0, 0))
     }
     let arrays = list_values.iter().map(|arr| &**arr).collect::<Vec<_>>();
-    let list_values: ArrayRef = arrow::compute::concatenate::concatenate(&arrays)
-        .unwrap()
-        .into();
+    let list_values: ArrayRef = arrow::compute::concatenate::concatenate(&arrays).unwrap();
     let data_type = ListArray::<i64>::default_datatype(list_values.data_type().clone());
-    let arr = Arc::new(ListArray::<i64>::from_data(
-        data_type,
-        offsets.into(),
-        list_values,
-        None,
-    )) as ArrayRef;
+    // Safety:
+    // offsets are monotonically increasing
+    let arr = unsafe {
+        Box::new(ListArray::<i64>::new(
+            data_type,
+            Offsets::new_unchecked(offsets).into(),
+            list_values,
+            None,
+        )) as ArrayRef
+    };
     let mut listarr = ListChunked::from_chunks(ca.name(), vec![arr]);
     if can_fast_explode {
         listarr.set_fast_explode()
@@ -318,7 +352,7 @@ impl<T: PolarsObject> AggList for ObjectChunked<T> {
                             (group_vals, idx.len() as IdxSize)
                         }
                         GroupsIndicator::Slice([first, len]) => {
-                            let group_vals = slice_from_offsets(self, first, len);
+                            let group_vals = _slice_from_offsets(self, first, len);
 
                             (group_vals, len)
                         }
@@ -345,13 +379,15 @@ impl<T: PolarsObject> AggList for ObjectChunked<T> {
         // meaning that the sentinel is heap allocated and the dereference of the
         // pointer does not fail
         pe.set_to_series_fn::<T>();
-        let extension_array = Arc::new(pe.take_and_forget()) as ArrayRef;
+        let extension_array = Box::new(pe.take_and_forget()) as ArrayRef;
         let extension_dtype = extension_array.data_type();
 
         let data_type = ListArray::<i64>::default_datatype(extension_dtype.clone());
-        let arr = Arc::new(ListArray::<i64>::from_data(
+        // Safety:
+        // offsets are monotonically increasing
+        let arr = Box::new(ListArray::<i64>::new(
             data_type,
-            offsets.into(),
+            Offsets::new_unchecked(offsets).into(),
             extension_array,
             None,
         )) as ArrayRef;
