@@ -6,17 +6,24 @@ use serde::{Deserialize, Serialize};
 
 use crate::prelude::*;
 
-#[derive(PartialEq, Eq, Clone, Default)]
+#[derive(Eq, Clone, Default)]
 #[cfg_attr(feature = "serde-lazy", derive(Serialize, Deserialize))]
 pub struct Schema {
     inner: PlIndexMap<String, DataType>,
 }
 
+// IndexMap does not care about order.
+impl PartialEq for Schema {
+    fn eq(&self, other: &Self) -> bool {
+        self.len() == other.len() && self.iter().zip(other.iter()).all(|(a, b)| a == b)
+    }
+}
+
 impl Debug for Schema {
     fn fmt(&self, f: &mut Formatter<'_>) -> std::fmt::Result {
         writeln!(f, "Schema:")?;
         for (name, dtype) in self.inner.iter() {
-            writeln!(f, "name: {}, data type: {:?}", name, dtype)?;
+            writeln!(f, "name: {name}, data type: {dtype:?}")?;
         }
         Ok(())
     }
@@ -139,6 +146,10 @@ impl Schema {
         self.inner.get_index(index)
     }
 
+    pub fn contains(&self, name: &str) -> bool {
+        self.get(name).is_some()
+    }
+
     pub fn get_index_mut(&mut self, index: usize) -> Option<(&mut String, &mut DataType)> {
         self.inner.get_index_mut(index)
     }
@@ -208,11 +219,7 @@ pub trait IndexOfSchema: Debug {
     fn try_index_of(&self, name: &str) -> PolarsResult<usize> {
         self.index_of(name).ok_or_else(|| {
             PolarsError::SchemaMisMatch(
-                format!(
-                    "Unable to get field named \"{}\" from schema: {:?}",
-                    name, self
-                )
-                .into(),
+                format!("Unable to get field named \"{name}\" from schema: {self:?}",).into(),
             )
         })
     }
