@@ -29,8 +29,8 @@ impl private::PrivateSeries for SeriesWrap<BinaryChunked> {
         self.0.explode_by_offsets(offsets)
     }
 
-    fn _set_sorted(&mut self, is_sorted: IsSorted) {
-        self.0.set_sorted2(is_sorted)
+    fn _set_sorted_flag(&mut self, is_sorted: IsSorted) {
+        self.0.set_sorted_flag(is_sorted)
     }
 
     unsafe fn equal_element(&self, idx_self: usize, idx_other: usize, other: &Series) -> bool {
@@ -95,10 +95,10 @@ impl private::PrivateSeries for SeriesWrap<BinaryChunked> {
 }
 
 impl SeriesTrait for SeriesWrap<BinaryChunked> {
-    fn is_sorted(&self) -> IsSorted {
-        if self.0.is_sorted() {
+    fn is_sorted_flag(&self) -> IsSorted {
+        if self.0.is_sorted_flag() {
             IsSorted::Ascending
-        } else if self.0.is_sorted_reverse() {
+        } else if self.0.is_sorted_reverse_flag() {
             IsSorted::Descending
         } else {
             IsSorted::Not
@@ -123,10 +123,6 @@ impl SeriesTrait for SeriesWrap<BinaryChunked> {
         self.0.shrink_to_fit()
     }
 
-    fn append_array(&mut self, other: ArrayRef) -> PolarsResult<()> {
-        self.0.append_array(other)
-    }
-
     fn slice(&self, offset: i64, length: usize) -> Series {
         self.0.slice(offset, length).into_series()
     }
@@ -198,8 +194,8 @@ impl SeriesTrait for SeriesWrap<BinaryChunked> {
 
         let mut out = ChunkTake::take_unchecked(&self.0, (&*idx).into());
 
-        if self.0.is_sorted() && (idx.is_sorted() || idx.is_sorted_reverse()) {
-            out.set_sorted2(idx.is_sorted2())
+        if self.0.is_sorted_flag() && (idx.is_sorted_flag() || idx.is_sorted_reverse_flag()) {
+            out.set_sorted_flag(idx.is_sorted_flag2())
         }
 
         Ok(out.into_series())
@@ -230,7 +226,7 @@ impl SeriesTrait for SeriesWrap<BinaryChunked> {
         self.0.cast(data_type)
     }
 
-    fn get(&self, index: usize) -> AnyValue {
+    fn get(&self, index: usize) -> PolarsResult<AnyValue> {
         self.0.get_any_value(index)
     }
 
