@@ -178,9 +178,9 @@ impl Series {
         &mut *chunks
     }
 
-    pub fn set_sorted(&mut self, sorted: IsSorted) {
+    pub fn set_sorted_flag(&mut self, sorted: IsSorted) {
         let inner = self._get_inner_mut();
-        inner._set_sorted(sorted)
+        inner._set_sorted_flag(sorted)
     }
 
     pub fn into_frame(self) -> DataFrame {
@@ -198,12 +198,6 @@ impl Series {
         self._get_inner_mut().shrink_to_fit()
     }
 
-    /// Append arrow array of same datatype.
-    pub fn append_array(&mut self, other: ArrayRef) -> PolarsResult<&mut Self> {
-        self._get_inner_mut().append_array(other)?;
-        Ok(self)
-    }
-
     /// Append in place. This is done by adding the chunks of `other` to this [`Series`].
     ///
     /// See [`ChunkedArray::append`] and [`ChunkedArray::extend`].
@@ -234,11 +228,17 @@ impl Series {
 
     /// Cast `[Series]` to another `[DataType]`
     pub fn cast(&self, dtype: &DataType) -> PolarsResult<Self> {
-        self.0.cast(dtype)
+        let len = self.len();
+        if self.null_count() == len {
+            Ok(Series::full_null(self.name(), len, dtype))
+        } else {
+            self.0.cast(dtype)
+        }
     }
 
     /// Compute the sum of all values in this Series.
-    /// Returns `None` if the array is empty or only contains null values.
+    /// Returns `Some(0)` if the array is empty, and `None` if the array only
+    /// contains null values.
     ///
     /// If the [`DataType`] is one of `{Int8, UInt8, Int16, UInt16}` the `Series` is
     /// first cast to `Int64` to prevent overflow issues.
@@ -517,11 +517,18 @@ impl Series {
     }
 
     /// Get the sum of the Series as a new Series of length 1.
+    /// Returns a Series with a single zeroed entry if self is an empty numeric series.
     ///
     /// If the [`DataType`] is one of `{Int8, UInt8, Int16, UInt16}` the `Series` is
     /// first cast to `Int64` to prevent overflow issues.
     pub fn sum_as_series(&self) -> Series {
         use DataType::*;
+        if self.is_empty() && self.dtype().is_numeric() {
+            return Series::new("", [0])
+                .cast(self.dtype())
+                .unwrap()
+                .sum_as_series();
+        }
         match self.dtype() {
             Int8 | UInt8 | Int16 | UInt16 => self.cast(&Int64).unwrap().sum_as_series(),
             _ => self._sum_as_series(),
@@ -594,7 +601,7 @@ impl Series {
                     let ca = self.f64().unwrap();
                     ca.cumsum(reverse).into_series()
                 }
-                dt => panic!("cumsum not supported for dtype: {:?}", dt),
+                dt => panic!("cumsum not supported for dtype: {dt:?}"),
             }
         }
         #[cfg(not(feature = "cum_agg"))]
@@ -635,7 +642,7 @@ impl Series {
                     let ca = self.f64().unwrap();
                     ca.cumprod(reverse).into_series()
                 }
-                dt => panic!("cumprod not supported for dtype: {:?}", dt),
+                dt => panic!("cumprod not supported for dtype: {dt:?}"),
             }
         }
         #[cfg(not(feature = "cum_agg"))]
@@ -671,7 +678,7 @@ impl Series {
                     let ca = self.f64().unwrap();
                     ca.prod_as_series()
                 }
-                dt => panic!("cumprod not supported for dtype: {:?}", dt),
+                dt => panic!("cumprod not supported for dtype: {dt:?}"),
             }
         }
         #[cfg(not(feature = "product"))]
@@ -723,7 +730,7 @@ impl Series {
                 .clone()
                 .into_time()
                 .into_series(),
-            dt => panic!("date not implemented for {:?}", dt),
+            dt => panic!("date not implemented for {dt:?}"),
         }
     }
 
@@ -742,7 +749,7 @@ impl Series {
                 .clone()
                 .into_date()
                 .into_series(),
-            dt => panic!("date not implemented for {:?}", dt),
+            dt => panic!("date not implemented for {dt:?}"),
         }
     }
     pub(crate) fn into_datetime(self, timeunit: TimeUnit, tz: Option<TimeZone>) -> Series {
@@ -766,7 +773,7 @@ impl Series {
                 .clone()
                 .into_datetime(timeunit, tz)
                 .into_series(),
-            dt => panic!("into_datetime not implemented for {:?}", dt),
+            dt => panic!("into_datetime not implemented for {dt:?}"),
         }
     }
 
@@ -790,7 +797,7 @@ impl Series {
                 .clone()
                 .into_duration(timeunit)
                 .into_series(),
-            dt => panic!("into_duration not implemented for {:?}", dt),
+            dt => panic!("into_duration not implemented for {dt:?}"),
         }
     }
 
@@ -812,7 +819,7 @@ impl Series {
             Float64 => a.f64().unwrap().abs().into_series(),
             dt => {
                 return Err(PolarsError::InvalidOperation(
-                    format!("abs not supported for series of type {:?}", dt).into(),
+                    format!("abs not supported for series of type {dt:?}").into(),
                 ));
             }
         };
@@ -821,14 +828,21 @@ impl Series {
 
     #[cfg(feature = "private")]
     // used for formatting
-    pub fn str_value(&self, index: usize) -> Cow<str> {
-        match self.0.get(index) {
+    pub fn str_value(&self, index: usize) -> PolarsResult<Cow<str>> {
+        let out = match self.0.get(index)? {
             AnyValue::Utf8(s) => Cow::Borrowed(s),
             AnyValue::Null => Cow::Borrowed("null"),
             #[cfg(feature = "dtype-categorical")]
-            AnyValue::Categorical(idx, rev) => Cow::Borrowed(rev.get(idx)),
-            av => Cow::Owned(format!("{}", av)),
-        }
+            AnyValue::Categorical(idx, rev, arr) => {
+                if arr.is_null() {
+                    Cow::Borrowed(rev.get(idx))
+                } else {
+                    unsafe { Cow::Borrowed(arr.deref_unchecked().value(idx as usize)) }
+                }
+            }
+            av => Cow::Owned(format!("{av}")),
+        };
+        Ok(out)
     }
     /// Get the head of the Series.
     pub fn head(&self, length: Option<usize>) -> Series {
@@ -853,10 +867,15 @@ impl Series {
                 let val = &[self.mean().map(|m| m as f32)];
                 Series::new(self.name(), val)
             }
-            dt if dt.is_numeric() => {
+            dt if dt.is_numeric() || matches!(dt, DataType::Boolean) => {
                 let val = &[self.mean()];
                 Series::new(self.name(), val)
             }
+            dt @ DataType::Duration(_) => {
+                Series::new(self.name(), &[self.mean().map(|v| v as i64)])
+                    .cast(dt)
+                    .unwrap()
+            }
             _ => return Series::full_null(self.name(), 1, self.dtype()),
         }
     }
@@ -1030,9 +1049,9 @@ mod test {
         let slice_2 = series.slice(-5, 5);
         let slice_3 = series.slice(0, 5);
 
-        assert_eq!(slice_1.get(0), AnyValue::Int64(3));
-        assert_eq!(slice_2.get(0), AnyValue::Int64(1));
-        assert_eq!(slice_3.get(0), AnyValue::Int64(1));
+        assert_eq!(slice_1.get(0).unwrap(), AnyValue::Int64(3));
+        assert_eq!(slice_2.get(0).unwrap(), AnyValue::Int64(1));
+        assert_eq!(slice_3.get(0).unwrap(), AnyValue::Int64(1));
     }
 
     #[test]
