@@ -1,31 +1,19 @@
+use polars_core::prelude::*;
 use rayon::prelude::*;
 
 use super::*;
+use crate::physical_plan::planner::create_physical_expr;
 use crate::physical_plan::state::ExecutionState;
+use crate::prelude::*;
 
-#[cfg(feature = "list_eval")]
-pub(super) fn prepare_eval_expr(mut expr: Expr) -> Expr {
-    expr.mutate().apply(|e| match e {
-        Expr::Column(name) => {
-            *name = Arc::from("");
-            true
-        }
-        Expr::Nth(_) => {
-            *e = Expr::Column(Arc::from(""));
-            true
-        }
-        _ => true,
-    });
-    expr
-}
-
-impl Expr {
+pub trait ExprEvalExtension: IntoExpr + Sized {
     /// Run an expression over a sliding window that increases `1` slot every iteration.
     ///
     /// # Warning
     /// this can be really slow as it can have `O(n^2)` complexity. Don't use this for operations
     /// that visit all elements.
-    pub fn cumulative_eval(self, expr: Expr, min_periods: usize, parallel: bool) -> Self {
+    fn cumulative_eval(self, expr: Expr, min_periods: usize, parallel: bool) -> Expr {
+        let this = self.into_expr();
         let expr2 = expr.clone();
         let func = move |mut s: Series| {
             let name = s.name().to_string();
@@ -33,8 +21,7 @@ impl Expr {
             let expr = expr.clone();
             let mut arena = Arena::with_capacity(10);
             let aexpr = to_aexpr(expr, &mut arena);
-            let planner = DefaultPlanner::default();
-            let phys_expr = planner.create_physical_expr(aexpr, Context::Default, &mut arena)?;
+            let phys_expr = create_physical_expr(aexpr, Context::Default, &arena, None)?;
 
             let state = ExecutionState::new();
 
@@ -49,7 +36,7 @@ impl Expr {
                         .into(),
                     ))
                 } else {
-                    Ok(out.get(0).into_static().unwrap())
+                    Ok(out.get(0).unwrap().into_static().unwrap())
                 }
             };
 
@@ -66,7 +53,7 @@ impl Expr {
                             Ok(AnyValue::Null)
                         }
                     })
-                    .collect::<Result<Vec<_>>>()?
+                    .collect::<PolarsResult<Vec<_>>>()?
             } else {
                 let mut df_container = DataFrame::new_no_checks(vec![]);
                 (1..s.len() + 1)
@@ -81,12 +68,12 @@ impl Expr {
                             Ok(AnyValue::Null)
                         }
                     })
-                    .collect::<Result<Vec<_>>>()?
+                    .collect::<PolarsResult<Vec<_>>>()?
             };
             Ok(Series::new(&name, avs))
         };
 
-        self.apply(
+        this.apply(
             func,
             GetOutput::map_field(move |f| {
                 // dummy df to determine output dtype
@@ -120,3 +107,5 @@ impl Expr {
         .with_fmt("expanding_eval")
     }
 }
+
+impl ExprEvalExtension for Expr {}
