@@ -1,10 +1,4 @@
-use std::borrow::Cow;
-
-use polars_core::prelude::*;
-
-use crate::physical_plan::executors::evaluate_physical_expressions;
-use crate::physical_plan::state::ExecutionState;
-use crate::prelude::*;
+use super::*;
 
 /// Take an input Executor (creates the input DataFrame)
 /// and a multiple PhysicalExpressions (create the output Series)
@@ -23,8 +17,7 @@ impl ProjectionExec {
         state: &mut ExecutionState,
         df: DataFrame,
     ) -> PolarsResult<DataFrame> {
-        state.set_schema(self.input_schema.clone());
-
+        #[allow(clippy::let_and_return)]
         let df = evaluate_physical_expressions(&df, &self.expr, state, self.has_windows);
 
         // this only runs during testing and check if the runtime type matches the predicted schema
@@ -39,7 +32,6 @@ impl ProjectionExec {
             });
         }
 
-        state.clear_expr_cache();
         df
     }
 }
