@@ -4,11 +4,14 @@ use polars_core::error::PolarsResult;
 use polars_core::schema::*;
 use polars_core::POOL;
 use polars_io::parquet::{BatchedParquetReader, ParquetReader};
-use polars_io::SerReader;
+#[cfg(feature = "parquet-async")]
+use polars_io::prelude::ParquetAsyncReader;
+use polars_io::{is_cloud_url, SerReader};
 use polars_plan::prelude::ParquetOptions;
 use polars_utils::IdxSize;
 
 use crate::operators::{DataChunk, PExecutionContext, Source, SourceResult};
+use crate::CHUNK_SIZE;
 
 pub struct ParquetSource {
     batched_reader: BatchedParquetReader,
@@ -29,12 +32,32 @@ impl ParquetSource {
                 .collect()
         });
 
-        let file = std::fs::File::open(path).unwrap();
-        let batched_reader = ParquetReader::new(file)
-            .with_n_rows(options.n_rows)
-            .with_row_count(options.row_count)
-            .with_projection(projection)
-            .batched()?;
+        let chunk_size = std::cmp::max(CHUNK_SIZE * 12 / POOL.current_num_threads(), 10_000);
+        let batched_reader = if is_cloud_url(&path) {
+            #[cfg(not(feature = "parquet-async"))]
+            {
+                panic!(
+                    "Feature parquet-async is required to access parquet files on cloud storage."
+                )
+            }
+            #[cfg(feature = "parquet-async")]
+            {
+                let uri = path.to_string_lossy();
+                ParquetAsyncReader::from_uri(&uri)?
+                    .with_n_rows(options.n_rows)
+                    .with_row_count(options.row_count)
+                    .with_projection(projection)
+                    .batched(chunk_size)?
+            }
+        } else {
+            let file = std::fs::File::open(path).unwrap();
+
+            ParquetReader::new(file)
+                .with_n_rows(options.n_rows)
+                .with_row_count(options.row_count)
+                .with_projection(projection)
+                .batched(chunk_size)?
+        };
 
         Ok(ParquetSource {
             batched_reader,
