@@ -3,6 +3,8 @@
 pub mod cat;
 #[cfg(feature = "dtype-categorical")]
 pub use cat::*;
+#[cfg(feature = "dtype-binary")]
+pub mod binary;
 #[cfg(feature = "temporal")]
 mod dt;
 mod expr;
@@ -368,10 +370,10 @@ impl Expr {
     }
 
     /// Compute the quantile per group.
-    pub fn quantile(self, quantile: f64, interpol: QuantileInterpolOptions) -> Self {
+    pub fn quantile(self, quantile: Expr, interpol: QuantileInterpolOptions) -> Self {
         AggExpr::Quantile {
             expr: Box::new(self),
-            quantile,
+            quantile: Box::new(quantile),
             interpol,
         }
         .into()
@@ -876,7 +878,18 @@ impl Expr {
     pub fn cumsum(self, reverse: bool) -> Self {
         self.apply(
             move |s: Series| Ok(s.cumsum(reverse)),
-            GetOutput::same_type(),
+            GetOutput::map_dtype(|dt| {
+                use DataType::*;
+                match dt {
+                    Boolean => UInt32,
+                    Int32 => Int32,
+                    UInt32 => UInt32,
+                    UInt64 => UInt64,
+                    Float32 => Float32,
+                    Float64 => Float64,
+                    _ => Int64,
+                }
+            }),
         )
         .with_fmt("cumsum")
     }
@@ -889,6 +902,8 @@ impl Expr {
             GetOutput::map_dtype(|dt| {
                 use DataType::*;
                 match dt {
+                    Boolean => Int64,
+                    UInt64 => UInt64,
                     Float32 => Float32,
                     Float64 => Float64,
                     _ => Int64,
@@ -1068,23 +1083,14 @@ impl Expr {
     /// │ i32    ┆ i32    │
     /// ╞════════╪════════╡
     /// │ 1      ┆ 16     │
-    /// ├╌╌╌╌╌╌╌╌┼╌╌╌╌╌╌╌╌┤
     /// │ 1      ┆ 16     │
-    /// ├╌╌╌╌╌╌╌╌┼╌╌╌╌╌╌╌╌┤
     /// │ 2      ┆ 13     │
-    /// ├╌╌╌╌╌╌╌╌┼╌╌╌╌╌╌╌╌┤
     /// │ 2      ┆ 13     │
-    /// ├╌╌╌╌╌╌╌╌┼╌╌╌╌╌╌╌╌┤
     /// │ ...    ┆ ...    │
-    /// ├╌╌╌╌╌╌╌╌┼╌╌╌╌╌╌╌╌┤
     /// │ 1      ┆ 16     │
-    /// ├╌╌╌╌╌╌╌╌┼╌╌╌╌╌╌╌╌┤
     /// │ 2      ┆ 13     │
-    /// ├╌╌╌╌╌╌╌╌┼╌╌╌╌╌╌╌╌┤
     /// │ 3      ┆ 15     │
-    /// ├╌╌╌╌╌╌╌╌┼╌╌╌╌╌╌╌╌┤
     /// │ 3      ┆ 15     │
-    /// ├╌╌╌╌╌╌╌╌┼╌╌╌╌╌╌╌╌┤
     /// │ 1      ┆ 16     │
     /// ╰────────┴────────╯
     /// ```
@@ -1510,13 +1516,13 @@ impl Expr {
     /// Add a suffix to the root column name.
     pub fn suffix(self, suffix: &str) -> Expr {
         let suffix = suffix.to_string();
-        self.map_alias(move |name| Ok(format!("{}{}", name, suffix)))
+        self.map_alias(move |name| Ok(format!("{name}{suffix}")))
     }
 
     /// Add a prefix to the root column name.
     pub fn prefix(self, prefix: &str) -> Expr {
         let prefix = prefix.to_string();
-        self.map_alias(move |name| Ok(format!("{}{}", prefix, name)))
+        self.map_alias(move |name| Ok(format!("{prefix}{name}")))
     }
 
     /// Exclude a column from a wildcard/regex selection.
@@ -1893,7 +1899,7 @@ impl Expr {
                     Float64 => Series::new(name, &[f64::INFINITY]),
                     dt => {
                         return Err(PolarsError::ComputeError(
-                            format!("cannot determine upper bound of dtype {}", dt).into(),
+                            format!("cannot determine upper bound of dtype {dt}").into(),
                         ))
                     }
                 };
@@ -1927,7 +1933,7 @@ impl Expr {
                     Float64 => Series::new(name, &[f64::NEG_INFINITY]),
                     dt => {
                         return Err(PolarsError::ComputeError(
-                            format!("cannot determine lower bound of dtype {}", dt).into(),
+                            format!("cannot determine lower bound of dtype {dt}").into(),
                         ))
                     }
                 };
@@ -2210,10 +2216,10 @@ impl Expr {
     /// # Warning
     /// This can lead to incorrect results if this `Series` is not sorted!!
     /// Use with care!
-    pub fn set_sorted(self, sorted: IsSorted) -> Expr {
+    pub fn set_sorted_flag(self, sorted: IsSorted) -> Expr {
         self.apply(
             move |mut s| {
-                s.set_sorted(sorted);
+                s.set_sorted_flag(sorted);
                 Ok(s)
             },
             GetOutput::same_type(),
@@ -2231,6 +2237,11 @@ impl Expr {
         string::StringNameSpace(self)
     }
 
+    #[cfg(feature = "dtype-binary")]
+    pub fn binary(self) -> binary::BinaryNameSpace {
+        binary::BinaryNameSpace(self)
+    }
+
     #[cfg(feature = "temporal")]
     pub fn dt(self) -> dt::DateLikeNameSpace {
         dt::DateLikeNameSpace(self)
