@@ -1,6 +1,6 @@
 use arrow::array::{Array, PrimitiveArray};
-use arrow::compute::cast::CastOptions;
-use arrow::compute::{cast::cast, temporal};
+use arrow::compute::cast::{cast, CastOptions};
+use arrow::compute::temporal;
 use arrow::error::Result as ArrowResult;
 use polars_arrow::export::arrow;
 use polars_core::prelude::*;
@@ -41,6 +41,16 @@ pub trait DatetimeMethods: AsDatetime {
         cast_and_apply(self.as_datetime(), temporal::year)
     }
 
+    fn iso_year(&self) -> Int32Chunked {
+        let ca = self.as_datetime();
+        let f = match ca.time_unit() {
+            TimeUnit::Nanoseconds => datetime_to_iso_year_ns,
+            TimeUnit::Microseconds => datetime_to_iso_year_us,
+            TimeUnit::Milliseconds => datetime_to_iso_year_ms,
+        };
+        ca.apply_kernel_cast::<Int32Type>(&f)
+    }
+
     /// Extract quarter from underlying NaiveDateTime representation.
     /// Quarters range from 1 to 4.
     fn quarter(&self) -> UInt32Chunked {
@@ -56,16 +66,10 @@ pub trait DatetimeMethods: AsDatetime {
         cast_and_apply(self.as_datetime(), temporal::month)
     }
 
-    /// Extract weekday from underlying NaiveDateTime representation.
-    /// Returns the weekday number where monday = 0 and sunday = 6
+    /// Extract ISO weekday from underlying NaiveDateTime representation.
+    /// Returns the weekday number where monday = 1 and sunday = 7
     fn weekday(&self) -> UInt32Chunked {
-        let ca = self.as_datetime();
-        let f = match ca.time_unit() {
-            TimeUnit::Nanoseconds => datetime_to_weekday_ns,
-            TimeUnit::Microseconds => datetime_to_weekday_us,
-            TimeUnit::Milliseconds => datetime_to_weekday_ms,
-        };
-        ca.apply_kernel_cast::<UInt32Type>(&f)
+        cast_and_apply(self.as_datetime(), temporal::weekday)
     }
 
     /// Returns the ISO week number starting from 1.
