@@ -1,7 +1,7 @@
 from __future__ import annotations
 
 import copy
-from datetime import date, datetime
+from datetime import date, datetime, time
 from typing import TYPE_CHECKING, Any, Callable
 
 import polars.internals as pli
@@ -33,7 +33,6 @@ class ExprListNameSpace:
         │ u32 │
         ╞═════╡
         │ 2   │
-        ├╌╌╌╌╌┤
         │ 1   │
         └─────┘
 
@@ -55,7 +54,6 @@ class ExprListNameSpace:
         │ i64    │
         ╞════════╡
         │ 1      │
-        ├╌╌╌╌╌╌╌╌┤
         │ 5      │
         └────────┘
 
@@ -77,7 +75,6 @@ class ExprListNameSpace:
         │ i64    │
         ╞════════╡
         │ 1      │
-        ├╌╌╌╌╌╌╌╌┤
         │ 3      │
         └────────┘
 
@@ -99,7 +96,6 @@ class ExprListNameSpace:
         │ i64    │
         ╞════════╡
         │ 1      │
-        ├╌╌╌╌╌╌╌╌┤
         │ 2      │
         └────────┘
 
@@ -121,7 +117,6 @@ class ExprListNameSpace:
         │ f64    │
         ╞════════╡
         │ 1.0    │
-        ├╌╌╌╌╌╌╌╌┤
         │ 2.5    │
         └────────┘
 
@@ -147,7 +142,6 @@ class ExprListNameSpace:
         │ list[i64] │
         ╞═══════════╡
         │ [1, 2, 3] │
-        ├╌╌╌╌╌╌╌╌╌╌╌┤
         │ [1, 2, 9] │
         └───────────┘
 
@@ -173,7 +167,6 @@ class ExprListNameSpace:
         │ list[i64] │
         ╞═══════════╡
         │ [1, 2, 3] │
-        ├╌╌╌╌╌╌╌╌╌╌╌┤
         │ [2, 1, 9] │
         └───────────┘
 
@@ -231,7 +224,6 @@ class ExprListNameSpace:
         │ list[str]       │
         ╞═════════════════╡
         │ ["a", "b", "c"] │
-        ├╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌┤
         │ ["x", "y", "z"] │
         └─────────────────┘
 
@@ -250,7 +242,7 @@ class ExprListNameSpace:
         other_list.insert(0, pli.wrap_expr(self._pyexpr))
         return pli.concat_list(other_list)
 
-    def get(self, index: int) -> pli.Expr:
+    def get(self, index: int | pli.Expr | str) -> pli.Expr:
         """
         Get the value by index in the sublists.
 
@@ -274,15 +266,17 @@ class ExprListNameSpace:
         │ i64  │
         ╞══════╡
         │ 3    │
-        ├╌╌╌╌╌╌┤
         │ null │
-        ├╌╌╌╌╌╌┤
         │ 1    │
         └──────┘
 
         """
+        index = pli.expr_to_lit_or_expr(index, str_to_lit=False)._pyexpr
         return pli.wrap_expr(self._pyexpr.lst_get(index))
 
+    def __getitem__(self, item: int) -> pli.Expr:
+        return self.get(item)
+
     def first(self) -> pli.Expr:
         """
         Get the first value of the sublists.
@@ -298,9 +292,7 @@ class ExprListNameSpace:
         │ i64  │
         ╞══════╡
         │ 3    │
-        ├╌╌╌╌╌╌┤
         │ null │
-        ├╌╌╌╌╌╌┤
         │ 1    │
         └──────┘
 
@@ -322,9 +314,7 @@ class ExprListNameSpace:
         │ i64  │
         ╞══════╡
         │ 1    │
-        ├╌╌╌╌╌╌┤
         │ null │
-        ├╌╌╌╌╌╌┤
         │ 2    │
         └──────┘
 
@@ -332,7 +322,7 @@ class ExprListNameSpace:
         return self.get(-1)
 
     def contains(
-        self, item: float | str | bool | int | date | datetime | pli.Expr
+        self, item: float | str | bool | int | date | datetime | time | pli.Expr
     ) -> pli.Expr:
         """
         Check if sublists contain the given item.
@@ -357,9 +347,7 @@ class ExprListNameSpace:
         │ bool  │
         ╞═══════╡
         │ true  │
-        ├╌╌╌╌╌╌╌┤
         │ false │
-        ├╌╌╌╌╌╌╌┤
         │ true  │
         └───────┘
 
@@ -394,7 +382,6 @@ class ExprListNameSpace:
         │ str   │
         ╞═══════╡
         │ a b c │
-        ├╌╌╌╌╌╌╌┤
         │ x y   │
         └───────┘
 
@@ -424,7 +411,6 @@ class ExprListNameSpace:
         │ u32 │
         ╞═════╡
         │ 0   │
-        ├╌╌╌╌╌┤
         │ 1   │
         └─────┘
 
@@ -454,7 +440,6 @@ class ExprListNameSpace:
         │ u32 │
         ╞═════╡
         │ 1   │
-        ├╌╌╌╌╌┤
         │ 0   │
         └─────┘
 
@@ -509,7 +494,9 @@ class ExprListNameSpace:
         """
         return pli.wrap_expr(self._pyexpr.lst_shift(periods))
 
-    def slice(self, offset: int, length: int | None = None) -> pli.Expr:
+    def slice(
+        self, offset: int | str | pli.Expr, length: int | str | pli.Expr | None = None
+    ) -> pli.Expr:
         """
         Slice every sublist.
 
@@ -533,9 +520,11 @@ class ExprListNameSpace:
         ]
 
         """
+        offset = pli.expr_to_lit_or_expr(offset, str_to_lit=False)._pyexpr
+        length = pli.expr_to_lit_or_expr(length, str_to_lit=False)._pyexpr
         return pli.wrap_expr(self._pyexpr.lst_slice(offset, length))
 
-    def head(self, n: int = 5) -> pli.Expr:
+    def head(self, n: int | str | pli.Expr = 5) -> pli.Expr:
         """
         Slice the first `n` values of every sublist.
 
@@ -558,7 +547,7 @@ class ExprListNameSpace:
         """
         return self.slice(0, n)
 
-    def tail(self, n: int = 5) -> pli.Expr:
+    def tail(self, n: int | str | pli.Expr = 5) -> pli.Expr:
         """
         Slice the last `n` values of every sublist.
 
@@ -579,12 +568,14 @@ class ExprListNameSpace:
         ]
 
         """
-        return self.slice(-n, n)
+        offset = -pli.expr_to_lit_or_expr(n, str_to_lit=False)
+        return self.slice(offset, n)
 
     def to_struct(
         self,
         n_field_strategy: ToStructStrategy = "first_non_null",
         name_generator: Callable[[int], str] | None = None,
+        upper_bound: int = 0,
     ) -> pli.Expr:
         """
         Convert the series of type ``List`` to a series of type ``Struct``.
@@ -596,6 +587,14 @@ class ExprListNameSpace:
         name_generator
             A custom function that can be used to generate the field names.
             Default field names are `field_0, field_1 .. field_n`
+        upper_bound
+            A polars `LazyFrame` needs to know the schema at all time.
+            The caller therefore must provide an `upper_bound` of
+            struct fields that will be set.
+            If this is incorrectly downstream operation may fail.
+            For instance an `all().sum()` expression will look in
+            the current schema to determine which columns to select.
+            It is adviced to set this value in a lazy query.
 
         Examples
         --------
@@ -608,7 +607,6 @@ class ExprListNameSpace:
         │ struct[3]  │
         ╞════════════╡
         │ {1,2,3}    │
-        ├╌╌╌╌╌╌╌╌╌╌╌╌┤
         │ {1,2,null} │
         └────────────┘
         >>> df.select(
@@ -623,7 +621,7 @@ class ExprListNameSpace:
 
         """
         return pli.wrap_expr(
-            self._pyexpr.lst_to_struct(n_field_strategy, name_generator)
+            self._pyexpr.lst_to_struct(n_field_strategy, name_generator, upper_bound)
         )
 
     def eval(self, expr: pli.Expr, parallel: bool = False) -> pli.Expr:
@@ -655,9 +653,7 @@ class ExprListNameSpace:
         │ i64 ┆ i64 ┆ list[f32]  │
         ╞═════╪═════╪════════════╡
         │ 1   ┆ 4   ┆ [1.0, 2.0] │
-        ├╌╌╌╌╌┼╌╌╌╌╌┼╌╌╌╌╌╌╌╌╌╌╌╌┤
         │ 8   ┆ 5   ┆ [2.0, 1.0] │
-        ├╌╌╌╌╌┼╌╌╌╌╌┼╌╌╌╌╌╌╌╌╌╌╌╌┤
         │ 3   ┆ 2   ┆ [2.0, 1.0] │
         └─────┴─────┴────────────┘
 
