@@ -1,18 +1,28 @@
 from __future__ import annotations
 
+import sys
+import typing
 from datetime import date, datetime, timedelta
 from typing import TYPE_CHECKING, Sequence, overload
 
 from polars import internals as pli
-from polars.datatypes import Categorical, Date, Float64
+from polars.datatypes import Categorical, Date, Float64, PolarsDataType
 from polars.utils import _datetime_to_pl_timestamp, _timedelta_to_pl_duration
 
+if sys.version_info >= (3, 10):
+    from typing import Literal
+else:
+    from typing_extensions import Literal
+
+
 try:
     from polars.polars import concat_df as _concat_df
     from polars.polars import concat_lf as _concat_lf
     from polars.polars import concat_series as _concat_series
     from polars.polars import py_date_range as _py_date_range
+    from polars.polars import py_date_range_lazy as _py_date_range_lazy
     from polars.polars import py_diag_concat_df as _diag_concat_df
+    from polars.polars import py_diag_concat_lf as _diag_concat_lf
     from polars.polars import py_hor_concat_df as _hor_concat_df
 
     _DOCUMENTING = False
@@ -37,6 +47,26 @@ def get_dummies(
         A subset of columns to convert to dummy variables. ``None`` means
         "all columns".
 
+    Examples
+    --------
+    >>> df = pl.DataFrame(
+    ...     {
+    ...         "foo": [1, 2],
+    ...         "bar": [3, 4],
+    ...         "ham": ["a", "b"],
+    ...     }
+    ... )
+    >>> pl.get_dummies(df.to_dummies(), columns=["foo", "bar"])
+    shape: (2, 6)
+    ┌───────┬───────┬───────┬───────┬───────┬───────┐
+    │ foo_1 ┆ foo_2 ┆ bar_3 ┆ bar_4 ┆ ham_a ┆ ham_b │
+    │ ---   ┆ ---   ┆ ---   ┆ ---   ┆ ---   ┆ ---   │
+    │ u8    ┆ u8    ┆ u8    ┆ u8    ┆ u8    ┆ u8    │
+    ╞═══════╪═══════╪═══════╪═══════╪═══════╪═══════╡
+    │ 1     ┆ 0     ┆ 1     ┆ 0     ┆ 1     ┆ 0     │
+    │ 0     ┆ 1     ┆ 0     ┆ 1     ┆ 0     ┆ 1     │
+    └───────┴───────┴───────┴───────┴───────┴───────┘
+
     """
     return df.to_dummies(columns=columns)
 
@@ -102,7 +132,7 @@ def concat(
     rechunk
         Make sure that all data is in contiguous memory.
     how : {'vertical', 'diagonal', 'horizontal'}
-        Only used if the items are DataFrames.
+        Lazy only supports the 'vertical' strategy.
 
         - Vertical: applies multiple `vstack` operations.
         - Diagonal: finds a union between the column schemas and fills missing column
@@ -110,7 +140,7 @@ def concat(
         - Horizontal: stacks Series horizontally and fills with nulls if the lengths
             don't match.
     parallel
-        Only relevant for LazyFrames. This determines if the concattenated
+        Only relevant for LazyFrames. This determines if the concatenated
         lazy computations may be executed in parallel.
 
     Examples
@@ -125,10 +155,68 @@ def concat(
     │ i64 ┆ i64 │
     ╞═════╪═════╡
     │ 1   ┆ 3   │
-    ├╌╌╌╌╌┼╌╌╌╌╌┤
     │ 2   ┆ 4   │
     └─────┴─────┘
 
+    >>> df_h1 = pl.DataFrame(
+    ...     {
+    ...         "l1": [1, 2],
+    ...         "l2": [3, 4],
+    ...     }
+    ... )
+    >>> df_h2 = pl.DataFrame(
+    ...     {
+    ...         "r1": [5, 6],
+    ...         "r2": [7, 8],
+    ...         "r3": [9, 10],
+    ...     }
+    ... )
+    >>> pl.concat(
+    ...     [
+    ...         df_h1,
+    ...         df_h2,
+    ...     ],
+    ...     how="horizontal",
+    ... )
+    shape: (2, 5)
+    ┌─────┬─────┬─────┬─────┬─────┐
+    │ l1  ┆ l2  ┆ r1  ┆ r2  ┆ r3  │
+    │ --- ┆ --- ┆ --- ┆ --- ┆ --- │
+    │ i64 ┆ i64 ┆ i64 ┆ i64 ┆ i64 │
+    ╞═════╪═════╪═════╪═════╪═════╡
+    │ 1   ┆ 3   ┆ 5   ┆ 7   ┆ 9   │
+    │ 2   ┆ 4   ┆ 6   ┆ 8   ┆ 10  │
+    └─────┴─────┴─────┴─────┴─────┘
+
+    >>> df_d1 = pl.DataFrame(
+    ...     {
+    ...         "a": [1],
+    ...         "b": [3],
+    ...     }
+    ... )
+    >>> df_d2 = pl.DataFrame(
+    ...     {
+    ...         "a": [2],
+    ...         "d": [4],
+    ...     }
+    ... )
+    >>> pl.concat(
+    ...     [
+    ...         df_d1,
+    ...         df_d2,
+    ...     ],
+    ...     how="diagonal",
+    ... )
+    shape: (2, 3)
+    ┌─────┬──────┬──────┐
+    │ a   ┆ b    ┆ d    │
+    │ --- ┆ ---  ┆ ---  │
+    │ i64 ┆ i64  ┆ i64  │
+    ╞═════╪══════╪══════╡
+    │ 1   ┆ 3    ┆ null │
+    │ 2   ┆ null ┆ 4    │
+    └─────┴──────┴──────┘
+
     """
     if not len(items) > 0:
         raise ValueError("cannot concat empty list")
@@ -144,10 +232,18 @@ def concat(
             out = pli.wrap_df(_hor_concat_df(items))
         else:
             raise ValueError(
-                f"how must be one of {{'vertical', 'diagonal'}}, got {how}"
+                f"how must be one of {{'vertical', 'diagonal', 'horizontal'}}, "
+                f"got {how}"
             )
     elif isinstance(first, pli.LazyFrame):
-        return pli.wrap_ldf(_concat_lf(items, rechunk, parallel))
+        if how == "vertical":
+            return pli.wrap_ldf(_concat_lf(items, rechunk, parallel))
+        if how == "diagonal":
+            return pli.wrap_ldf(_diag_concat_lf(items, rechunk, parallel))
+        else:
+            raise ValueError(
+                "Lazy only allows {{'vertical', 'diagonal'}} concat strategy."
+            )
     elif isinstance(first, pli.Series):
         out = pli.wrap_s(_concat_series(items))
     elif isinstance(first, pli.Expr):
@@ -174,14 +270,78 @@ def _interval_granularity(interval: str) -> str:
     return interval[-2:].lstrip("0123456789")
 
 
+@overload
 def date_range(
-    low: date | datetime,
-    high: date | datetime,
+    low: pli.Expr,
+    high: date | datetime | pli.Expr | str,
     interval: str | timedelta,
+    *,
+    lazy: Literal[False] = ...,
     closed: ClosedWindow = "both",
     name: str | None = None,
     time_unit: TimeUnit | None = None,
+    time_zone: str | None = None,
+) -> pli.Expr:
+    ...
+
+
+@overload
+def date_range(
+    low: date | datetime | pli.Expr | str,
+    high: pli.Expr,
+    interval: str | timedelta,
+    *,
+    lazy: Literal[False] = ...,
+    closed: ClosedWindow = "both",
+    name: str | None = None,
+    time_unit: TimeUnit | None = None,
+    time_zone: str | None = None,
+) -> pli.Expr:
+    ...
+
+
+@overload
+def date_range(
+    low: date | datetime | str,
+    high: date | datetime | str,
+    interval: str | timedelta,
+    *,
+    lazy: Literal[False] = ...,
+    closed: ClosedWindow = "both",
+    name: str | None = None,
+    time_unit: TimeUnit | None = None,
+    time_zone: str | None = None,
 ) -> pli.Series:
+    ...
+
+
+@overload
+def date_range(
+    low: date | datetime | pli.Expr | str,
+    high: date | datetime | pli.Expr | str,
+    interval: str | timedelta,
+    *,
+    lazy: Literal[True],
+    closed: ClosedWindow = "both",
+    name: str | None = None,
+    time_unit: TimeUnit | None = None,
+    time_zone: str | None = None,
+) -> pli.Expr:
+    ...
+
+
+@typing.no_type_check
+def date_range(
+    low: date | datetime | pli.Expr | str,
+    high: date | datetime | pli.Expr | str,
+    interval: str | timedelta,
+    *,
+    lazy: bool = False,
+    closed: ClosedWindow = "both",
+    name: str | None = None,
+    time_unit: TimeUnit | None = None,
+    time_zone: str | None = None,
+) -> pli.Series | pli.Expr:
     """
     Create a range of type `Datetime` (or `Date`).
 
@@ -195,12 +355,17 @@ def date_range(
         Interval periods. It can be a python timedelta object, like
         ``timedelta(days=10)``, or a polars duration string, such as ``3d12h4m25s``
         representing 3 days, 12 hours, 4 minutes, and 25 seconds.
+    lazy:
+        Return an expression.
     closed : {'both', 'left', 'right', 'none'}
         Define whether the temporal window interval is closed or not.
     name
         Name of the output Series.
     time_unit : {None, 'ns', 'us', 'ms'}
         Set the time unit.
+    time_zone:
+        Optional timezone
+
 
     Notes
     -----
@@ -217,9 +382,9 @@ def date_range(
     Using polars duration string to specify the interval:
 
     >>> from datetime import date
-    >>> pl.date_range(date(2022, 1, 1), date(2022, 3, 1), "1mo", name="drange")
+    >>> pl.date_range(date(2022, 1, 1), date(2022, 3, 1), "1mo", name="dtrange")
     shape: (3,)
-    Series: 'drange' [date]
+    Series: 'dtrange' [date]
     [
         2022-01-01
         2022-02-01
@@ -247,15 +412,56 @@ def date_range(
         1985-01-10 00:00:00
     ]
 
+    Specify a time zone
+
+    >>> pl.date_range(
+    ...     datetime(2022, 1, 1),
+    ...     datetime(2022, 3, 1),
+    ...     "1mo",
+    ...     time_zone="America/New_York",
+    ... )
+    shape: (3,)
+    Series: '' [datetime[μs, America/New_York]]
+    [
+        2022-01-01 00:00:00 EST
+        2022-02-01 00:00:00 EST
+        2022-03-01 00:00:00 EST
+    ]
+
     """
+    if name is None:
+        name = ""
     if isinstance(interval, timedelta):
         interval = _timedelta_to_pl_duration(interval)
     elif " " in interval:
         interval = interval.replace(" ", "")
 
+    if isinstance(low, pli.Expr) or isinstance(high, pli.Expr) or lazy:
+        low = pli.expr_to_lit_or_expr(low, str_to_lit=True)._pyexpr
+        high = pli.expr_to_lit_or_expr(high, str_to_lit=True)._pyexpr
+        return pli.wrap_expr(
+            _py_date_range_lazy(low, high, interval, closed, name, time_zone)
+        )
+
     low, low_is_date = _ensure_datetime(low)
     high, high_is_date = _ensure_datetime(high)
 
+    if low.tzinfo is not None or time_zone is not None:
+        if low.tzinfo != high.tzinfo:
+            raise ValueError(
+                "Cannot mix different timezone aware datetimes."
+                f" Got: '{low.tzinfo}' and '{high.tzinfo}'."
+            )
+
+        if time_zone is not None and low.tzinfo is not None:
+            if str(low.tzinfo) != time_zone:
+                raise ValueError(
+                    "Given time_zone is different from that timezone aware datetimes."
+                    f" Given: '{time_zone}', got: '{low.tzinfo}'."
+                )
+        if time_zone is None:
+            time_zone = str(low.tzinfo)
+
     tu: TimeUnit
     if time_unit is not None:
         tu = time_unit
@@ -266,10 +472,9 @@ def date_range(
 
     start = _datetime_to_pl_timestamp(low, tu)
     stop = _datetime_to_pl_timestamp(high, tu)
-    if name is None:
-        name = ""
-
-    dt_range = pli.wrap_s(_py_date_range(start, stop, interval, closed, name, tu))
+    dt_range = pli.wrap_s(
+        _py_date_range(start, stop, interval, closed, name, tu, time_zone)
+    )
     if (
         low_is_date
         and high_is_date
@@ -324,21 +529,13 @@ def cut(
     │ f64  ┆ f64         ┆ cat          │
     ╞══════╪═════════════╪══════════════╡
     │ -3.0 ┆ -1.0        ┆ (-inf, -1.0] │
-    ├╌╌╌╌╌╌┼╌╌╌╌╌╌╌╌╌╌╌╌╌┼╌╌╌╌╌╌╌╌╌╌╌╌╌╌┤
     │ -2.5 ┆ -1.0        ┆ (-inf, -1.0] │
-    ├╌╌╌╌╌╌┼╌╌╌╌╌╌╌╌╌╌╌╌╌┼╌╌╌╌╌╌╌╌╌╌╌╌╌╌┤
     │ -2.0 ┆ -1.0        ┆ (-inf, -1.0] │
-    ├╌╌╌╌╌╌┼╌╌╌╌╌╌╌╌╌╌╌╌╌┼╌╌╌╌╌╌╌╌╌╌╌╌╌╌┤
     │ -1.5 ┆ -1.0        ┆ (-inf, -1.0] │
-    ├╌╌╌╌╌╌┼╌╌╌╌╌╌╌╌╌╌╌╌╌┼╌╌╌╌╌╌╌╌╌╌╌╌╌╌┤
     │ ...  ┆ ...         ┆ ...          │
-    ├╌╌╌╌╌╌┼╌╌╌╌╌╌╌╌╌╌╌╌╌┼╌╌╌╌╌╌╌╌╌╌╌╌╌╌┤
     │ 1.0  ┆ 1.0         ┆ (-1.0, 1.0]  │
-    ├╌╌╌╌╌╌┼╌╌╌╌╌╌╌╌╌╌╌╌╌┼╌╌╌╌╌╌╌╌╌╌╌╌╌╌┤
     │ 1.5  ┆ inf         ┆ (1.0, inf]   │
-    ├╌╌╌╌╌╌┼╌╌╌╌╌╌╌╌╌╌╌╌╌┼╌╌╌╌╌╌╌╌╌╌╌╌╌╌┤
     │ 2.0  ┆ inf         ┆ (1.0, inf]   │
-    ├╌╌╌╌╌╌┼╌╌╌╌╌╌╌╌╌╌╌╌╌┼╌╌╌╌╌╌╌╌╌╌╌╌╌╌┤
     │ 2.5  ┆ inf         ┆ (1.0, inf]   │
     └──────┴─────────────┴──────────────┘
 
@@ -387,6 +584,7 @@ def align_frames(
     *frames: pli.DataFrame,
     on: str | pli.Expr | Sequence[str] | Sequence[pli.Expr] | Sequence[str | pli.Expr],
     select: str | pli.Expr | Sequence[str | pli.Expr] | None = None,
+    reverse: bool | Sequence[bool] = False,
 ) -> list[pli.DataFrame]:
     ...
 
@@ -396,6 +594,7 @@ def align_frames(
     *frames: pli.LazyFrame,
     on: str | pli.Expr | Sequence[str] | Sequence[pli.Expr] | Sequence[str | pli.Expr],
     select: str | pli.Expr | Sequence[str | pli.Expr] | None = None,
+    reverse: bool | Sequence[bool] = False,
 ) -> list[pli.LazyFrame]:
     ...
 
@@ -404,14 +603,15 @@ def align_frames(
     *frames: pli.DataFrame | pli.LazyFrame,
     on: str | pli.Expr | Sequence[str] | Sequence[pli.Expr] | Sequence[str | pli.Expr],
     select: str | pli.Expr | Sequence[str | pli.Expr] | None = None,
+    reverse: bool | Sequence[bool] = False,
 ) -> list[pli.DataFrame] | list[pli.LazyFrame]:
-    """
-    Align a sequence of frames using the values from one or more columns as a key.
+    r"""
+    Align a sequence of frames using the unique values from one or more columns as a key.
 
     Frames that do not contain the given key values have rows injected (with nulls
     filling the non-key columns), and each resulting frame is sorted by the key.
 
-    The original column order of input frames is not changed unless `select` is
+    The original column order of input frames is not changed unless ``select`` is
     specified (in which case the final column order is determined from that).
 
     Note that this does not result in a joined frame - you receive the same number
@@ -423,10 +623,13 @@ def align_frames(
     frames
         sequence of DataFrames or LazyFrames.
     on
-        one or more columns whose values will be used to align the frames.
+        one or more columns whose unique values will be used to align the frames.
     select
         optional post-alignment column select to constrain and/or order
         the columns returned from the newly aligned frames.
+    reverse
+        sort the alignment column values in descending order; can be a single
+        boolean or a list of booleans associated with each column in ``on``.
 
     Examples
     --------
@@ -450,8 +653,10 @@ def align_frames(
     ...         "x": [2.0, 5.0],
     ...         "y": [2.5, 2.0],
     ...     }
-    ... )
-
+    ... )  # doctest: +IGNORE_RESULT
+    >>>
+    >>> pl.Config.set_tbl_formatting("UTF8_FULL")  # doctest: +IGNORE_RESULT
+    #
     # df1                              df2                              df3
     # shape: (3, 3)                    shape: (3, 3)                    shape: (2, 3)
     # ┌────────────┬─────┬──────┐      ┌────────────┬─────┬──────┐      ┌────────────┬─────┬─────┐
@@ -459,16 +664,37 @@ def align_frames(
     # │ ---        ┆ --- ┆ ---  │      │ ---        ┆ --- ┆ ---  │      │ ---        ┆ --- ┆ --- │
     # │ date       ┆ f64 ┆ f64  │      │ date       ┆ f64 ┆ f64  │      │ date       ┆ f64 ┆ f64 │
     # ╞════════════╪═════╪══════╡      ╞════════════╪═════╪══════╡      ╞════════════╪═════╪═════╡
-    # │ 2022-09-01 ┆ 3.5 ┆ 10.0 │      │ 2022-09-02 ┆ 8.0 ┆ 1.5  │      │ 2022-09-03 ┆ 2.0 ┆ 2.5 │
-    # ├╌╌╌╌╌╌╌╌╌╌╌╌┼╌╌╌╌╌┼╌╌╌╌╌╌┤      ├╌╌╌╌╌╌╌╌╌╌╌╌┼╌╌╌╌╌┼╌╌╌╌╌╌┤      ├╌╌╌╌╌╌╌╌╌╌╌╌┼╌╌╌╌╌┼╌╌╌╌╌┤
-    # │ 2022-09-02 ┆ 4.0 ┆ 2.5  │      │ 2022-09-03 ┆ 1.0 ┆ 12.0 │      │ 2022-09-02 ┆ 5.0 ┆ 2.0 │
-    # ├╌╌╌╌╌╌╌╌╌╌╌╌┼╌╌╌╌╌┼╌╌╌╌╌╌┤      ├╌╌╌╌╌╌╌╌╌╌╌╌┼╌╌╌╌╌┼╌╌╌╌╌╌┤      └────────────┴─────┴─────┘
-    # │ 2022-09-03 ┆ 1.0 ┆ 1.5  │      │ 2022-09-01 ┆ 3.5 ┆ 5.0  │
+    # │ 2022-09-01 ┆ 3.5 ┆ 10.0 │\  ,->│ 2022-09-02 ┆ 8.0 ┆ 1.5  │\  ,->│ 2022-09-03 ┆ 2.0 ┆ 2.5 │
+    # ├╌╌╌╌╌╌╌╌╌╌╌╌┼╌╌╌╌╌┼╌╌╌╌╌╌┤ \/   ├╌╌╌╌╌╌╌╌╌╌╌╌┼╌╌╌╌╌┼╌╌╌╌╌╌┤ \/   ├╌╌╌╌╌╌╌╌╌╌╌╌┼╌╌╌╌╌┼╌╌╌╌╌┤
+    # │ 2022-09-02 ┆ 4.0 ┆ 2.5  │_/\,->│ 2022-09-03 ┆ 1.0 ┆ 12.0 │_/`-->│ 2022-09-02 ┆ 5.0 ┆ 2.0 │
+    # ├╌╌╌╌╌╌╌╌╌╌╌╌┼╌╌╌╌╌┼╌╌╌╌╌╌┤  /\  ├╌╌╌╌╌╌╌╌╌╌╌╌┼╌╌╌╌╌┼╌╌╌╌╌╌┤      └────────────┴─────┴─────┘
+    # │ 2022-09-03 ┆ 1.0 ┆ 1.5  │_/  `>│ 2022-09-01 ┆ 3.5 ┆ 5.0  │-//-
     # └────────────┴─────┴──────┘      └────────────┴─────┴──────┘
-
-    >>> # align frames on the values in "dt", but keep only cols "x" and "y":
-    >>> af1, af2, af3 = pl.align_frames(df1, df2, df3, on="dt", select=["x", "y"])
-
+    ...
+    >>> # align frames by the "dt" column:
+    >>> af1, af2, af3 = pl.align_frames(
+    ...     df1, df2, df3, on="dt"
+    ... )  # doctest: +IGNORE_RESULT
+    #
+    # df1                              df2                              df3
+    # shape: (3, 3)                    shape: (3, 3)                    shape: (3, 3)
+    # ┌────────────┬─────┬──────┐      ┌────────────┬─────┬──────┐      ┌────────────┬──────┬──────┐
+    # │ dt         ┆ x   ┆ y    │      │ dt         ┆ x   ┆ y    │      │ dt         ┆ x    ┆ y    │
+    # │ ---        ┆ --- ┆ ---  │      │ ---        ┆ --- ┆ ---  │      │ ---        ┆ ---  ┆ ---  │
+    # │ date       ┆ f64 ┆ f64  │      │ date       ┆ f64 ┆ f64  │      │ date       ┆ f64  ┆ f64  │
+    # ╞════════════╪═════╪══════╡      ╞════════════╪═════╪══════╡      ╞════════════╪══════╪══════╡
+    # │ 2022-09-01 ┆ 3.5 ┆ 10.0 │----->│ 2022-09-01 ┆ 3.5 ┆ 5.0  │----->│ 2022-09-01 ┆ null ┆ null │
+    # ├╌╌╌╌╌╌╌╌╌╌╌╌┼╌╌╌╌╌┼╌╌╌╌╌╌┤      ├╌╌╌╌╌╌╌╌╌╌╌╌┼╌╌╌╌╌┼╌╌╌╌╌╌┤      ├╌╌╌╌╌╌╌╌╌╌╌╌┼╌╌╌╌╌╌┼╌╌╌╌╌╌┤
+    # │ 2022-09-02 ┆ 4.0 ┆ 2.5  │----->│ 2022-09-02 ┆ 8.0 ┆ 1.5  │----->│ 2022-09-02 ┆ 5.0  ┆ 2.0  │
+    # ├╌╌╌╌╌╌╌╌╌╌╌╌┼╌╌╌╌╌┼╌╌╌╌╌╌┤      ├╌╌╌╌╌╌╌╌╌╌╌╌┼╌╌╌╌╌┼╌╌╌╌╌╌┤      ├╌╌╌╌╌╌╌╌╌╌╌╌┼╌╌╌╌╌╌┼╌╌╌╌╌╌┤
+    # │ 2022-09-03 ┆ 1.0 ┆ 1.5  │----->│ 2022-09-03 ┆ 1.0 ┆ 12.0 │----->│ 2022-09-03 ┆ 2.0  ┆ 2.5  │
+    # └────────────┴─────┴──────┘      └────────────┴─────┴──────┘      └────────────┴──────┴──────┘
+    ...
+    >>> # align frames by "dt", but keep only cols "x" and "y":
+    >>> af1, af2, af3 = pl.align_frames(
+    ...     df1, df2, df3, on="dt", select=["x", "y"]
+    ... )  # doctest: +IGNORE_RESULT
+    #
     # af1                 af2                 af3
     # shape: (3, 3)       shape: (3, 3)       shape: (3, 3)
     # ┌─────┬──────┐      ┌─────┬──────┐      ┌──────┬──────┐
@@ -482,8 +708,8 @@ def align_frames(
     # ├╌╌╌╌╌┼╌╌╌╌╌╌┤      ├╌╌╌╌╌┼╌╌╌╌╌╌┤      ├╌╌╌╌╌╌┼╌╌╌╌╌╌┤
     # │ 1.0 ┆ 1.5  │      │ 1.0 ┆ 12.0 │      │ 2.0  ┆ 2.5  │
     # └─────┴──────┘      └─────┴──────┘      └──────┴──────┘
-
-    >>> # now frames are aligned, can easily calculate the row-wise dot product:
+    ...
+    >>> # now data is aligned, can easily calculate the row-wise dot product:
     >>> (af1 * af2 * af3).fill_null(0).select(pl.sum(pl.col("*")).alias("dot"))
     shape: (3, 1)
     ┌───────┐
@@ -498,39 +724,6 @@ def align_frames(
     │ 47.0  │
     └───────┘
 
-    >>> # as above, but keeping the alignment column ("dt") in the final frame:
-    >>> af1, af2, af3 = pl.align_frames(df1, df2, df3, on="dt")
-
-    # af1                              af2                              af3
-    # shape: (3, 3)                    shape: (3, 3)                    shape: (3, 3)
-    # ┌────────────┬─────┬──────┐      ┌────────────┬─────┬──────┐      ┌────────────┬──────┬──────┐
-    # │ dt         ┆ x   ┆ y    │      │ dt         ┆ x   ┆ y    │      │ dt         ┆ x    ┆ y    │
-    # │ ---        ┆ --- ┆ ---  │      │ ---        ┆ --- ┆ ---  │      │ ---        ┆ ---  ┆ ---  │
-    # │ date       ┆ f64 ┆ f64  │      │ date       ┆ f64 ┆ f64  │      │ date       ┆ f64  ┆ f64  │
-    # ╞════════════╪═════╪══════╡      ╞════════════╪═════╪══════╡      ╞════════════╪══════╪══════╡
-    # │ 2022-09-01 ┆ 3.5 ┆ 10.0 │      │ 2022-09-01 ┆ 3.5 ┆ 5.0  │      │ 2022-09-01 ┆ null ┆ null │
-    # ├╌╌╌╌╌╌╌╌╌╌╌╌┼╌╌╌╌╌┼╌╌╌╌╌╌┤      ├╌╌╌╌╌╌╌╌╌╌╌╌┼╌╌╌╌╌┼╌╌╌╌╌╌┤      ├╌╌╌╌╌╌╌╌╌╌╌╌┼╌╌╌╌╌╌┼╌╌╌╌╌╌┤
-    # │ 2022-09-02 ┆ 4.0 ┆ 2.5  │      │ 2022-09-02 ┆ 8.0 ┆ 1.5  │      │ 2022-09-02 ┆ 5.0  ┆ 2.0  │
-    # ├╌╌╌╌╌╌╌╌╌╌╌╌┼╌╌╌╌╌┼╌╌╌╌╌╌┤      ├╌╌╌╌╌╌╌╌╌╌╌╌┼╌╌╌╌╌┼╌╌╌╌╌╌┤      ├╌╌╌╌╌╌╌╌╌╌╌╌┼╌╌╌╌╌╌┼╌╌╌╌╌╌┤
-    # │ 2022-09-03 ┆ 1.0 ┆ 1.5  │      │ 2022-09-03 ┆ 1.0 ┆ 12.0 │      │ 2022-09-03 ┆ 2.0  ┆ 2.5  │
-    # └────────────┴─────┴──────┘      └────────────┴─────┴──────┘      └────────────┴──────┴──────┘
-
-    >>> (af1[["x", "y"]] * af2[["x", "y"]] * af3[["x", "y"]]).fill_null(0).select(
-    ...     pl.sum(pl.col("*")).alias("dot")
-    ... ).insert_at_idx(0, af1["dt"])
-    shape: (3, 2)
-    ┌────────────┬───────┐
-    │ dt         ┆ dot   │
-    │ ---        ┆ ---   │
-    │ date       ┆ f64   │
-    ╞════════════╪═══════╡
-    │ 2022-09-01 ┆ 0.0   │
-    ├╌╌╌╌╌╌╌╌╌╌╌╌┼╌╌╌╌╌╌╌┤
-    │ 2022-09-02 ┆ 167.5 │
-    ├╌╌╌╌╌╌╌╌╌╌╌╌┼╌╌╌╌╌╌╌┤
-    │ 2022-09-03 ┆ 47.0  │
-    └────────────┴───────┘
-
     """  # noqa: E501
     if not frames:
         return []  # type: ignore[return-value]
@@ -539,24 +732,98 @@ def align_frames(
             "Input frames must be of a consistent type (all LazyFrame or all DataFrame)"
         )
 
+    # establish the superset of all "on" column values, sort, and cache
     eager = isinstance(frames[0], pli.DataFrame)
-    alignment_frame = concat([df.lazy().select(on) for df in frames]).unique(
-        maintain_order=False
+    alignment_frame = (
+        concat([df.lazy().select(on) for df in frames])
+        .unique(maintain_order=False)
+        .sort(by=on, reverse=reverse)
     )
-    if eager:  # collect once, outside the alignment joins
-        alignment_frame = alignment_frame.collect().lazy()
-
+    alignment_frame = (
+        alignment_frame.collect().lazy() if eager else alignment_frame.cache()
+    )
+    # finally, align all frames
     aligned_frames = [
         alignment_frame.join(
             other=df.lazy(),
             on=alignment_frame.columns,
             how="left",
-        )
-        .select(df.columns)
-        .sort(by=on)
+        ).select(df.columns)
         for df in frames
     ]
     if select is not None:
         aligned_frames = [df.select(select) for df in aligned_frames]
 
     return [df.collect() for df in aligned_frames] if eager else aligned_frames
+
+
+def ones(n: int, dtype: PolarsDataType | None = None) -> pli.Series:
+    """
+    Return a new Series of given length and type, filled with ones.
+
+    Parameters
+    ----------
+    n
+        Number of elements in the ``Series``
+    dtype
+        DataType of the elements, defaults to ``polars.Float64``
+
+    Notes
+    -----
+    In the lazy API you should probably not use this, but use ``lit(1)``
+    instead.
+
+    Examples
+    --------
+    >>> pl.ones(5, pl.Int64)
+    shape: (5,)
+    Series: '' [i64]
+    [
+        1
+        1
+        1
+        1
+        1
+    ]
+
+    """
+    s = pli.Series([1.0])
+    if dtype:
+        s = s.cast(dtype)
+    return s.new_from_index(0, n)
+
+
+def zeros(n: int, dtype: PolarsDataType | None = None) -> pli.Series:
+    """
+    Return a new Series of given length and type, filled with zeros.
+
+    Parameters
+    ----------
+    n
+        Number of elements in the ``Series``
+    dtype
+        DataType of the elements, defaults to ``polars.Float64``
+
+    Notes
+    -----
+    In the lazy API you should probably not use this, but use ``lit(0)``
+    instead.
+
+    Examples
+    --------
+    >>> pl.zeros(5, pl.Int64)
+    shape: (5,)
+    Series: '' [i64]
+    [
+        0
+        0
+        0
+        0
+        0
+    ]
+
+    """
+    s = pli.Series([0.0])
+    if dtype:
+        s = s.cast(dtype)
+    return s.new_from_index(0, n)
