@@ -2,13 +2,13 @@ from __future__ import annotations
 
 import sys
 from datetime import date, datetime, time, timedelta
-from inspect import isclass
-from typing import TYPE_CHECKING, Any, Callable, Sequence, cast, overload
+from typing import TYPE_CHECKING, Any, Callable, Sequence, overload
 
 from polars import internals as pli
 from polars.datatypes import (
     DTYPE_TEMPORAL_UNITS,
     DataType,
+    DataTypeClass,
     Date,
     Datetime,
     Duration,
@@ -26,6 +26,7 @@ from polars.utils import (
     _datetime_to_pl_timestamp,
     _time_to_pl_time,
     _timedelta_to_pl_timedelta,
+    deprecated_alias,
 )
 
 try:
@@ -86,6 +87,7 @@ def col(
     - a single column by name
     - all columns by using a wildcard `"*"`
     - column by regular expression if the regex starts with `^` and ends with `$`
+    - all columns with the same dtype by using a Polars type
 
     Parameters
     ----------
@@ -99,6 +101,7 @@ def col(
     ...         "ham": [1, 2, 3],
     ...         "hamburger": [11, 22, 33],
     ...         "foo": [3, 2, 1],
+    ...         "bar": ["a", "b", "c"],
     ...     }
     ... )
     >>> df.select(pl.col("foo"))
@@ -109,24 +112,20 @@ def col(
     │ i64 │
     ╞═════╡
     │ 3   │
-    ├╌╌╌╌╌┤
     │ 2   │
-    ├╌╌╌╌╌┤
     │ 1   │
     └─────┘
     >>> df.select(pl.col("*"))
-    shape: (3, 3)
-    ┌─────┬───────────┬─────┐
-    │ ham ┆ hamburger ┆ foo │
-    │ --- ┆ ---       ┆ --- │
-    │ i64 ┆ i64       ┆ i64 │
-    ╞═════╪═══════════╪═════╡
-    │ 1   ┆ 11        ┆ 3   │
-    ├╌╌╌╌╌┼╌╌╌╌╌╌╌╌╌╌╌┼╌╌╌╌╌┤
-    │ 2   ┆ 22        ┆ 2   │
-    ├╌╌╌╌╌┼╌╌╌╌╌╌╌╌╌╌╌┼╌╌╌╌╌┤
-    │ 3   ┆ 33        ┆ 1   │
-    └─────┴───────────┴─────┘
+    shape: (3, 4)
+    ┌─────┬───────────┬─────┬─────┐
+    │ ham ┆ hamburger ┆ foo ┆ bar │
+    │ --- ┆ ---       ┆ --- ┆ --- │
+    │ i64 ┆ i64       ┆ i64 ┆ str │
+    ╞═════╪═══════════╪═════╪═════╡
+    │ 1   ┆ 11        ┆ 3   ┆ a   │
+    │ 2   ┆ 22        ┆ 2   ┆ b   │
+    │ 3   ┆ 33        ┆ 1   ┆ c   │
+    └─────┴───────────┴─────┴─────┘
     >>> df.select(pl.col("^ham.*$"))
     shape: (3, 2)
     ┌─────┬───────────┐
@@ -135,24 +134,20 @@ def col(
     │ i64 ┆ i64       │
     ╞═════╪═══════════╡
     │ 1   ┆ 11        │
-    ├╌╌╌╌╌┼╌╌╌╌╌╌╌╌╌╌╌┤
     │ 2   ┆ 22        │
-    ├╌╌╌╌╌┼╌╌╌╌╌╌╌╌╌╌╌┤
     │ 3   ┆ 33        │
     └─────┴───────────┘
     >>> df.select(pl.col("*").exclude("ham"))
-    shape: (3, 2)
-    ┌───────────┬─────┐
-    │ hamburger ┆ foo │
-    │ ---       ┆ --- │
-    │ i64       ┆ i64 │
-    ╞═══════════╪═════╡
-    │ 11        ┆ 3   │
-    ├╌╌╌╌╌╌╌╌╌╌╌┼╌╌╌╌╌┤
-    │ 22        ┆ 2   │
-    ├╌╌╌╌╌╌╌╌╌╌╌┼╌╌╌╌╌┤
-    │ 33        ┆ 1   │
-    └───────────┴─────┘
+    shape: (3, 3)
+    ┌───────────┬─────┬─────┐
+    │ hamburger ┆ foo ┆ bar │
+    │ ---       ┆ --- ┆ --- │
+    │ i64       ┆ i64 ┆ str │
+    ╞═══════════╪═════╪═════╡
+    │ 11        ┆ 3   ┆ a   │
+    │ 22        ┆ 2   ┆ b   │
+    │ 33        ┆ 1   ┆ c   │
+    └───────────┴─────┴─────┘
     >>> df.select(pl.col(["hamburger", "foo"]))
     shape: (3, 2)
     ┌───────────┬─────┐
@@ -161,21 +156,40 @@ def col(
     │ i64       ┆ i64 │
     ╞═══════════╪═════╡
     │ 11        ┆ 3   │
-    ├╌╌╌╌╌╌╌╌╌╌╌┼╌╌╌╌╌┤
     │ 22        ┆ 2   │
-    ├╌╌╌╌╌╌╌╌╌╌╌┼╌╌╌╌╌┤
     │ 33        ┆ 1   │
     └───────────┴─────┘
+    >>> # Select columns with a dtype
+    >>> df.select(pl.col(pl.Utf8))
+    shape: (3, 1)
+    ┌─────┐
+    │ bar │
+    │ --- │
+    │ str │
+    ╞═════╡
+    │ a   │
+    │ b   │
+    │ c   │
+    └─────┘
+    >>> # Select columns from a list of dtypes
+    >>> df.select(pl.col([pl.Int64, pl.Float64]))
+    shape: (3, 3)
+    ┌─────┬───────────┬─────┐
+    │ ham ┆ hamburger ┆ foo │
+    │ --- ┆ ---       ┆ --- │
+    │ i64 ┆ i64       ┆ i64 │
+    ╞═════╪═══════════╪═════╡
+    │ 1   ┆ 11        ┆ 3   │
+    │ 2   ┆ 22        ┆ 2   │
+    │ 3   ┆ 33        ┆ 1   │
+    └─────┴───────────┴─────┘
 
     """
     if isinstance(name, pli.Series):
         name = name.to_list()  # type: ignore[assignment]
 
-    # note: we need the typing.cast call here twice to make mypy happy under Python 3.7
-    # On Python 3.10, it is not needed. We use cast as it works across versions,
-    # ignoring the typing error would lead to unneeded ignores under Python 3.10.
-    if isclass(name) and issubclass(cast(type, name), DataType):
-        name = [cast(type, name)]
+    if isinstance(name, DataTypeClass):
+        name = [name]
 
     if isinstance(name, DataType):
         return pli.wrap_expr(_dtype_cols([name]))
@@ -192,7 +206,7 @@ def col(
 
 def element() -> pli.Expr:
     """
-    Alias for an element in evaluated in an `eval` expression.
+    Alias for an element being evaluated in an `eval` expression.
 
     Examples
     --------
@@ -209,9 +223,7 @@ def element() -> pli.Expr:
     │ i64 ┆ i64 ┆ list[f32]  │
     ╞═════╪═════╪════════════╡
     │ 1   ┆ 4   ┆ [1.0, 2.0] │
-    ├╌╌╌╌╌┼╌╌╌╌╌┼╌╌╌╌╌╌╌╌╌╌╌╌┤
     │ 8   ┆ 5   ┆ [2.0, 1.0] │
-    ├╌╌╌╌╌┼╌╌╌╌╌┼╌╌╌╌╌╌╌╌╌╌╌╌┤
     │ 3   ┆ 2   ┆ [2.0, 1.0] │
     └─────┴─────┴────────────┘
 
@@ -228,9 +240,7 @@ def element() -> pli.Expr:
     │ i64 ┆ i64 ┆ list[i64]   │
     ╞═════╪═════╪═════════════╡
     │ 1   ┆ 4   ┆ [2, 8]      │
-    ├╌╌╌╌╌┼╌╌╌╌╌┼╌╌╌╌╌╌╌╌╌╌╌╌╌┤
     │ 8   ┆ 5   ┆ [16, 10]    │
-    ├╌╌╌╌╌┼╌╌╌╌╌┼╌╌╌╌╌╌╌╌╌╌╌╌╌┤
     │ 3   ┆ 2   ┆ [6, 4]      │
     └─────┴─────┴─────────────┘
 
@@ -266,6 +276,29 @@ def count(column: str | pli.Series | None = None) -> pli.Expr | int:
         * ``str`` : count the values in this column.
         * ``None`` : count the number of values in this context.
 
+    Examples
+    --------
+    >>> df = pl.DataFrame({"a": [1, 8, 3], "b": [4, 5, 2], "c": ["foo", "bar", "foo"]})
+    >>> df.select(pl.count())
+    shape: (1, 1)
+    ┌───────┐
+    │ count │
+    │ ---   │
+    │ u32   │
+    ╞═══════╡
+    │ 3     │
+    └───────┘
+    >>> df.groupby("c", maintain_order=True).agg(pl.count())
+    shape: (2, 2)
+    ┌─────┬───────┐
+    │ c   ┆ count │
+    │ --- ┆ ---   │
+    │ str ┆ u32   │
+    ╞═════╪═══════╡
+    │ foo ┆ 2     │
+    │ bar ┆ 1     │
+    └─────┴───────┘
+
     """
     if column is None:
         return pli.wrap_expr(_count())
@@ -296,7 +329,25 @@ def std(column: pli.Series, ddof: int = 1) -> float | None:
 
 
 def std(column: str | pli.Series, ddof: int = 1) -> pli.Expr | float | None:
-    """Get the standard deviation."""
+    """
+    Get the standard deviation.
+
+    Examples
+    --------
+    >>> df = pl.DataFrame({"a": [1, 8, 3], "b": [4, 5, 2], "c": ["foo", "bar", "foo"]})
+    >>> df.select(pl.std("a"))
+    shape: (1, 1)
+    ┌──────────┐
+    │ a        │
+    │ ---      │
+    │ f64      │
+    ╞══════════╡
+    │ 3.605551 │
+    └──────────┘
+    >>> df["a"].std()
+    3.605551275463989
+
+    """
     if isinstance(column, pli.Series):
         return column.std(ddof)
     return col(column).std(ddof)
@@ -313,7 +364,25 @@ def var(column: pli.Series, ddof: int = 1) -> float | None:
 
 
 def var(column: str | pli.Series, ddof: int = 1) -> pli.Expr | float | None:
-    """Get the variance."""
+    """
+    Get the variance.
+
+    Examples
+    --------
+    >>> df = pl.DataFrame({"a": [1, 8, 3], "b": [4, 5, 2], "c": ["foo", "bar", "foo"]})
+    >>> df.select(pl.var("a"))
+    shape: (1, 1)
+    ┌──────┐
+    │ a    │
+    │ ---  │
+    │ f64  │
+    ╞══════╡
+    │ 13.0 │
+    └──────┘
+    >>> df["a"].var()
+    13.0
+
+    """
     if isinstance(column, pli.Series):
         return column.var(ddof)
     return col(column).var(ddof)
@@ -341,6 +410,49 @@ def max(column: str | Sequence[pli.Expr | str] | pli.Series) -> pli.Expr | Any:
         - Union[str, Series] -> aggregate the maximum value of that column.
         - List[Expr] -> aggregate the maximum value horizontally.
 
+    Examples
+    --------
+    >>> df = pl.DataFrame({"a": [1, 8, 3], "b": [4, 5, 2], "c": ["foo", "bar", "foo"]})
+
+    Get the maximum value by columns with a string column name
+
+    >>> df.select(pl.max("a"))
+    shape: (1, 1)
+    ┌─────┐
+    │ a   │
+    │ --- │
+    │ i64 │
+    ╞═════╡
+    │ 8   │
+    └─────┘
+
+    Get the maximum value by row with a list of columns/expressions
+
+    >>> df.select(pl.max(["a", "b"]))
+    shape: (3, 1)
+    ┌─────┐
+    │ max │
+    │ --- │
+    │ i64 │
+    ╞═════╡
+    │ 4   │
+    │ 8   │
+    │ 3   │
+    └─────┘
+
+    To aggregate the maximums for more than one column/expression
+    use ``pl.col(list).max()`` instead:
+
+    >>> df.select(pl.col(["a", "b"]).max())
+    shape: (1, 2)
+    ┌─────┬─────┐
+    │ a   ┆ b   │
+    │ --- ┆ --- │
+    │ i64 ┆ i64 │
+    ╞═════╪═════╡
+    │ 8   ┆ 5   │
+    └─────┴─────┘
+
     """
     if isinstance(column, pli.Series):
         return column.max()
@@ -375,6 +487,49 @@ def min(
         - Union[str, Series] -> aggregate the sum value of that column.
         - List[Expr] -> aggregate the min value horizontally.
 
+    Examples
+    --------
+    >>> df = pl.DataFrame({"a": [1, 8, 3], "b": [4, 5, 2], "c": ["foo", "bar", "foo"]})
+
+    Get the minimum value by columns with a string column name
+
+    >>> df.select(pl.min("a"))
+    shape: (1, 1)
+    ┌─────┐
+    │ a   │
+    │ --- │
+    │ i64 │
+    ╞═════╡
+    │ 1   │
+    └─────┘
+
+    Get the minimum value by row with a list of columns/expressions
+
+    >>> df.select(pl.min(["a", "b"]))
+    shape: (3, 1)
+    ┌─────┐
+    │ min │
+    │ --- │
+    │ i64 │
+    ╞═════╡
+    │ 1   │
+    │ 5   │
+    │ 2   │
+    └─────┘
+
+    To aggregate the minimums for more than one column/expression
+    use ``pl.col(list).min()`` instead:
+
+    >>> df.select(pl.col(["a", "b"]).min())
+    shape: (1, 2)
+    ┌─────┬─────┐
+    │ a   ┆ b   │
+    │ --- ┆ --- │
+    │ i64 ┆ i64 │
+    ╞═════╪═════╡
+    │ 1   ┆ 2   │
+    └─────┴─────┘
+
     """
     if isinstance(column, pli.Series):
         return column.min()
@@ -435,7 +590,6 @@ def sum(
     │ i64 ┆ i64 ┆ i64 │
     ╞═════╪═════╪═════╡
     │ 1   ┆ 3   ┆ 5   │
-    ├╌╌╌╌╌┼╌╌╌╌╌┼╌╌╌╌╌┤
     │ 2   ┆ 4   ┆ 6   │
     └─────┴─────┴─────┘
 
@@ -461,7 +615,6 @@ def sum(
     │ i64 ┆ i64 ┆ i64 ┆ i64 │
     ╞═════╪═════╪═════╪═════╡
     │ 1   ┆ 3   ┆ 5   ┆ 6   │
-    ├╌╌╌╌╌┼╌╌╌╌╌┼╌╌╌╌╌┼╌╌╌╌╌┤
     │ 2   ┆ 4   ┆ 6   ┆ 8   │
     └─────┴─────┴─────┴─────┘
 
@@ -507,7 +660,25 @@ def mean(column: pli.Series) -> float:
 
 
 def mean(column: str | pli.Series) -> pli.Expr | float:
-    """Get the mean value."""
+    """
+    Get the mean value.
+
+    Examples
+    --------
+    >>> df = pl.DataFrame({"a": [1, 8, 3], "b": [4, 5, 2], "c": ["foo", "bar", "foo"]})
+    >>> df.select(pl.mean("a"))
+    shape: (1, 1)
+    ┌─────┐
+    │ a   │
+    │ --- │
+    │ f64 │
+    ╞═════╡
+    │ 4.0 │
+    └─────┘
+    >>> pl.mean(df["a"])
+    4.0
+
+    """
     if isinstance(column, pli.Series):
         return column.mean()
     return col(column).mean()
@@ -524,7 +695,25 @@ def avg(column: pli.Series) -> float:
 
 
 def avg(column: str | pli.Series) -> pli.Expr | float:
-    """Alias for mean."""
+    """
+    Alias for mean.
+
+    Examples
+    --------
+    >>> df = pl.DataFrame({"a": [1, 8, 3], "b": [4, 5, 2], "c": ["foo", "bar", "foo"]})
+    >>> df.select(pl.avg("a"))
+    shape: (1, 1)
+    ┌─────┐
+    │ a   │
+    │ --- │
+    │ f64 │
+    ╞═════╡
+    │ 4.0 │
+    └─────┘
+    >>> pl.avg(df["a"])
+    4.0
+
+    """
     return mean(column)
 
 
@@ -539,7 +728,25 @@ def median(column: pli.Series) -> float | int:
 
 
 def median(column: str | pli.Series) -> pli.Expr | float | int:
-    """Get the median value."""
+    """
+    Get the median value.
+
+    Examples
+    --------
+    >>> df = pl.DataFrame({"a": [1, 8, 3], "b": [4, 5, 2], "c": ["foo", "bar", "foo"]})
+    >>> df.select(pl.median("a"))
+    shape: (1, 1)
+    ┌─────┐
+    │ a   │
+    │ --- │
+    │ f64 │
+    ╞═════╡
+    │ 3.0 │
+    └─────┘
+    >>> pl.median(df["a"])
+    3.0
+
+    """
     if isinstance(column, pli.Series):
         return column.median()
     return col(column).median()
@@ -556,7 +763,25 @@ def n_unique(column: pli.Series) -> int:
 
 
 def n_unique(column: str | pli.Series) -> pli.Expr | int:
-    """Count unique values."""
+    """
+    Count unique values.
+
+    Examples
+    --------
+    >>> df = pl.DataFrame({"a": [1, 8, 1], "b": [4, 5, 2], "c": ["foo", "bar", "foo"]})
+    >>> df.select(pl.n_unique("a"))
+    shape: (1, 1)
+    ┌─────┐
+    │ a   │
+    │ --- │
+    │ u32 │
+    ╞═════╡
+    │ 2   │
+    └─────┘
+    >>> pl.n_unique(df["a"])
+    2
+
+    """
     if isinstance(column, pli.Series):
         return column.n_unique()
     return col(column).n_unique()
@@ -589,6 +814,32 @@ def first(column: str | pli.Series | None = None) -> pli.Expr | Any:
     - str -> syntactic sugar for `pl.col(..).first()`
     - Series -> Take first value in `Series`
 
+    Examples
+    --------
+    >>> df = pl.DataFrame({"a": [1, 8, 3], "b": [4, 5, 2], "c": ["foo", "bar", "foo"]})
+    >>> df.select(pl.first())
+    shape: (3, 1)
+    ┌─────┐
+    │ a   │
+    │ --- │
+    │ i64 │
+    ╞═════╡
+    │ 1   │
+    │ 8   │
+    │ 3   │
+    └─────┘
+    >>> df.select(pl.first("a"))
+    shape: (1, 1)
+    ┌─────┐
+    │ a   │
+    │ --- │
+    │ i64 │
+    ╞═════╡
+    │ 1   │
+    └─────┘
+    >>> pl.first(df["a"])
+    1
+
     """
     if column is None:
         return pli.wrap_expr(_first())
@@ -626,6 +877,32 @@ def last(column: str | pli.Series | None = None) -> pli.Expr:
     - str -> syntactic sugar for `pl.col(..).last()`
     - Series -> Take last value in `Series`
 
+    Examples
+    --------
+    >>> df = pl.DataFrame({"a": [1, 8, 3], "b": [4, 5, 2], "c": ["foo", "bar", "foo"]})
+    >>> df.select(pl.last())
+    shape: (3, 1)
+    ┌─────┐
+    │ c   │
+    │ --- │
+    │ str │
+    ╞═════╡
+    │ foo │
+    │ bar │
+    │ foo │
+    └─────┘
+    >>> df.select(pl.last("a"))
+    shape: (1, 1)
+    ┌─────┐
+    │ a   │
+    │ --- │
+    │ i64 │
+    ╞═════╡
+    │ 3   │
+    └─────┘
+    >>> pl.last(df["a"])
+    3
+
     """
     if column is None:
         return pli.wrap_expr(_last())
@@ -659,6 +936,38 @@ def head(column: str | pli.Series, n: int = 10) -> pli.Expr | pli.Series:
     n
         Number of rows to return.
 
+    Examples
+    --------
+    >>> df = pl.DataFrame({"a": [1, 8, 3], "b": [4, 5, 2], "c": ["foo", "bar", "foo"]})
+    >>> df.select(pl.head("a"))
+    shape: (3, 1)
+    ┌─────┐
+    │ a   │
+    │ --- │
+    │ i64 │
+    ╞═════╡
+    │ 1   │
+    │ 8   │
+    │ 3   │
+    └─────┘
+    >>> df.select(pl.head("a", 2))
+    shape: (2, 1)
+    ┌─────┐
+    │ a   │
+    │ --- │
+    │ i64 │
+    ╞═════╡
+    │ 1   │
+    │ 8   │
+    └─────┘
+    >>> pl.head(df["a"], 2)
+    shape: (2,)
+    Series: 'a' [i64]
+    [
+        1
+        8
+    ]
+
     """
     if isinstance(column, pli.Series):
         return column.head(n)
@@ -686,6 +995,38 @@ def tail(column: str | pli.Series, n: int = 10) -> pli.Expr | pli.Series:
     n
         Number of rows to return.
 
+    Examples
+    --------
+    >>> df = pl.DataFrame({"a": [1, 8, 3], "b": [4, 5, 2], "c": ["foo", "bar", "foo"]})
+    >>> df.select(pl.tail("a"))
+    shape: (3, 1)
+    ┌─────┐
+    │ a   │
+    │ --- │
+    │ i64 │
+    ╞═════╡
+    │ 1   │
+    │ 8   │
+    │ 3   │
+    └─────┘
+    >>> df.select(pl.tail("a", 2))
+    shape: (2, 1)
+    ┌─────┐
+    │ a   │
+    │ --- │
+    │ i64 │
+    ╞═════╡
+    │ 8   │
+    │ 3   │
+    └─────┘
+    >>> pl.tail(df["a"], 2)
+    shape: (2,)
+    Series: 'a' [i64]
+    [
+        8
+        3
+    ]
+
     """
     if isinstance(column, pli.Series):
         return column.tail(n)
@@ -785,7 +1126,6 @@ def lit(
 
     except AttributeError:
         item = value
-
     return pli.wrap_expr(pylit(item, allow_object))
 
 
@@ -841,7 +1181,6 @@ def cumsum(
     │ i64 ┆ i64 ┆ i64 │
     ╞═════╪═════╪═════╡
     │ 1   ┆ 3   ┆ 5   │
-    ├╌╌╌╌╌┼╌╌╌╌╌┼╌╌╌╌╌┤
     │ 2   ┆ 4   ┆ 6   │
     └─────┴─────┴─────┘
 
@@ -855,7 +1194,6 @@ def cumsum(
     │ i64 │
     ╞═════╡
     │ 1   │
-    ├╌╌╌╌╌┤
     │ 3   │
     └─────┘
 
@@ -869,7 +1207,6 @@ def cumsum(
     │ i64 ┆ i64 ┆ i64 ┆ struct[2] │
     ╞═════╪═════╪═════╪═══════════╡
     │ 1   ┆ 3   ┆ 5   ┆ {1,6}     │
-    ├╌╌╌╌╌┼╌╌╌╌╌┼╌╌╌╌╌┼╌╌╌╌╌╌╌╌╌╌╌┤
     │ 2   ┆ 4   ┆ 6   ┆ {2,8}     │
     └─────┴─────┴─────┴───────────┘
 
@@ -903,6 +1240,19 @@ def spearman_rank_corr(
         Defaults to `False` where `NaN` are regarded as larger than any finite number
         and thus lead to the highest rank.
 
+    Examples
+    --------
+    >>> df = pl.DataFrame({"a": [1, 8, 3], "b": [4, 5, 2], "c": ["foo", "bar", "foo"]})
+    >>> df.select(pl.spearman_rank_corr("a", "b"))
+    shape: (1, 1)
+    ┌─────┐
+    │ a   │
+    │ --- │
+    │ f64 │
+    ╞═════╡
+    │ 0.5 │
+    └─────┘
+
     """
     if isinstance(a, str):
         a = col(a)
@@ -926,6 +1276,19 @@ def pearson_corr(a: str | pli.Expr, b: str | pli.Expr, ddof: int = 1) -> pli.Exp
     ddof
         Delta degrees of freedom
 
+    Examples
+    --------
+    >>> df = pl.DataFrame({"a": [1, 8, 3], "b": [4, 5, 2], "c": ["foo", "bar", "foo"]})
+    >>> df.select(pl.pearson_corr("a", "b"))
+    shape: (1, 1)
+    ┌──────────┐
+    │ a        │
+    │ ---      │
+    │ f64      │
+    ╞══════════╡
+    │ 0.544705 │
+    └──────────┘
+
     """
     if isinstance(a, str):
         a = col(a)
@@ -948,6 +1311,19 @@ def cov(
     b
         Column name or Expression.
 
+    Examples
+    --------
+    >>> df = pl.DataFrame({"a": [1, 8, 3], "b": [4, 5, 2], "c": ["foo", "bar", "foo"]})
+    >>> df.select(pl.cov("a", "b"))
+    shape: (1, 1)
+    ┌─────┐
+    │ a   │
+    │ --- │
+    │ f64 │
+    ╞═════╡
+    │ 3.0 │
+    └─────┘
+
     """
     if isinstance(a, str):
         a = col(a)
@@ -1208,9 +1584,7 @@ def exclude(
     │ i64 ┆ str  ┆ f64  │
     ╞═════╪══════╪══════╡
     │ 1   ┆ a    ┆ null │
-    ├╌╌╌╌╌┼╌╌╌╌╌╌┼╌╌╌╌╌╌┤
     │ 2   ┆ b    ┆ 2.5  │
-    ├╌╌╌╌╌┼╌╌╌╌╌╌┼╌╌╌╌╌╌┤
     │ 3   ┆ null ┆ 1.5  │
     └─────┴──────┴──────┘
 
@@ -1224,9 +1598,7 @@ def exclude(
     │ i64 ┆ f64  │
     ╞═════╪══════╡
     │ 1   ┆ null │
-    ├╌╌╌╌╌┼╌╌╌╌╌╌┤
     │ 2   ┆ 2.5  │
-    ├╌╌╌╌╌┼╌╌╌╌╌╌┤
     │ 3   ┆ 1.5  │
     └─────┴──────┘
 
@@ -1240,9 +1612,7 @@ def exclude(
     │ f64  │
     ╞══════╡
     │ null │
-    ├╌╌╌╌╌╌┤
     │ 2.5  │
-    ├╌╌╌╌╌╌┤
     │ 1.5  │
     └──────┘
 
@@ -1256,9 +1626,7 @@ def exclude(
     │ str  │
     ╞══════╡
     │ a    │
-    ├╌╌╌╌╌╌┤
     │ b    │
-    ├╌╌╌╌╌╌┤
     │ null │
     └──────┘
 
@@ -1312,7 +1680,9 @@ def groups(column: str) -> pli.Expr:
 
 
 def quantile(
-    column: str, quantile: float, interpolation: RollingInterpolationMethod = "nearest"
+    column: str,
+    quantile: float | pli.Expr,
+    interpolation: RollingInterpolationMethod = "nearest",
 ) -> pli.Expr:
     """
     Syntactic sugar for `pl.col("foo").quantile(..)`.
@@ -1488,7 +1858,6 @@ def duration(
     ╞════════════╪════════════╪═════════════════════╪══════════════╪═════════════════════╡
     │ 2022-01-08 ┆ 2022-01-02 ┆ 2022-01-01 00:00:01 ┆ 2022-01-01   ┆ 2022-01-01 01:00:00 │
     │ 00:00:00   ┆ 00:00:00   ┆                     ┆ 00:00:00.001 ┆                     │
-    ├╌╌╌╌╌╌╌╌╌╌╌╌┼╌╌╌╌╌╌╌╌╌╌╌╌┼╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌┼╌╌╌╌╌╌╌╌╌╌╌╌╌╌┼╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌┤
     │ 2022-01-16 ┆ 2022-01-04 ┆ 2022-01-02 00:00:02 ┆ 2022-01-02   ┆ 2022-01-02 02:00:00 │
     │ 00:00:00   ┆ 00:00:00   ┆                     ┆ 00:00:00.002 ┆                     │
     └────────────┴────────────┴─────────────────────┴──────────────┴─────────────────────┘
@@ -1649,9 +2018,7 @@ def concat_str(exprs: Sequence[pli.Expr | str] | pli.Expr, sep: str = "") -> pli
     │ i64 ┆ str  ┆ str  ┆ str           │
     ╞═════╪══════╪══════╪═══════════════╡
     │ 1   ┆ dogs ┆ play ┆ 2 dogs play   │
-    ├╌╌╌╌╌┼╌╌╌╌╌╌┼╌╌╌╌╌╌┼╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌┤
     │ 2   ┆ cats ┆ swim ┆ 4 cats swim   │
-    ├╌╌╌╌╌┼╌╌╌╌╌╌┼╌╌╌╌╌╌┼╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌┤
     │ 3   ┆ null ┆ walk ┆ null          │
     └─────┴──────┴──────┴───────────────┘
 
@@ -1692,9 +2059,7 @@ def format(fstring: str, *args: pli.Expr | str) -> pli.Expr:
     │ str         │
     ╞═════════════╡
     │ foo_a_bar_1 │
-    ├╌╌╌╌╌╌╌╌╌╌╌╌╌┤
     │ foo_b_bar_2 │
-    ├╌╌╌╌╌╌╌╌╌╌╌╌╌┤
     │ foo_c_bar_3 │
     └─────────────┘
 
@@ -1752,13 +2117,9 @@ def concat_list(exprs: Sequence[str | pli.Expr | pli.Series] | pli.Expr) -> pli.
     │ list[f64]         │
     ╞═══════════════════╡
     │ [null, null, 1.0] │
-    ├╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌┤
     │ [null, 1.0, 2.0]  │
-    ├╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌┤
     │ [1.0, 2.0, 9.0]   │
-    ├╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌┤
     │ [2.0, 9.0, 2.0]   │
-    ├╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌┤
     │ [9.0, 2.0, 13.0]  │
     └───────────────────┘
 
@@ -1767,6 +2128,7 @@ def concat_list(exprs: Sequence[str | pli.Expr | pli.Series] | pli.Expr) -> pli.
     return pli.wrap_expr(_concat_lst(exprs))
 
 
+@deprecated_alias(allow_streaming="streaming")
 def collect_all(
     lazy_frames: Sequence[pli.LazyFrame],
     type_coercion: bool = True,
@@ -1777,7 +2139,7 @@ def collect_all(
     no_optimization: bool = False,
     slice_pushdown: bool = True,
     common_subplan_elimination: bool = True,
-    allow_streaming: bool = False,
+    streaming: bool = False,
 ) -> list[pli.DataFrame]:
     """
     Collect multiple LazyFrames at the same time.
@@ -1804,7 +2166,7 @@ def collect_all(
         Slice pushdown optimization.
     common_subplan_elimination
         Will try to cache branching subplans that occur on self-joins or unions.
-    allow_streaming
+    streaming
         Run parts of the query in a streaming fashion (this is in an alpha state)
 
     Returns
@@ -1828,7 +2190,7 @@ def collect_all(
             simplify_expression,
             slice_pushdown,
             common_subplan_elimination,
-            allow_streaming,
+            streaming,
         )
         prepared.append(ldf)
 
@@ -1873,9 +2235,7 @@ def select(
     │ i64 │
     ╞═════╡
     │ 1   │
-    ├╌╌╌╌╌┤
     │ 2   │
-    ├╌╌╌╌╌┤
     │ 1   │
     └─────┘
 
@@ -1938,7 +2298,6 @@ def struct(
     │ struct[4]           │
     ╞═════════════════════╡
     │ {1,"a",true,[1, 2]} │
-    ├╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌┤
     │ {2,"b",null,[3]}    │
     └─────────────────────┘
 
@@ -1955,11 +2314,8 @@ def struct(
     │ i64 ┆ str   ┆ i64 ┆ struct[2]   │
     ╞═════╪═══════╪═════╪═════════════╡
     │ 1   ┆ one   ┆ 9   ┆ {1,"one"}   │
-    ├╌╌╌╌╌┼╌╌╌╌╌╌╌┼╌╌╌╌╌┼╌╌╌╌╌╌╌╌╌╌╌╌╌┤
     │ 2   ┆ two   ┆ 8   ┆ {2,"two"}   │
-    ├╌╌╌╌╌┼╌╌╌╌╌╌╌┼╌╌╌╌╌┼╌╌╌╌╌╌╌╌╌╌╌╌╌┤
     │ 3   ┆ three ┆ 7   ┆ {3,"three"} │
-    ├╌╌╌╌╌┼╌╌╌╌╌╌╌┼╌╌╌╌╌┼╌╌╌╌╌╌╌╌╌╌╌╌╌┤
     │ 4   ┆ four  ┆ 6   ┆ {4,"four"}  │
     └─────┴───────┴─────┴─────────────┘
 
@@ -2131,11 +2487,8 @@ def coalesce(
     │ f64  ┆ f64  ┆ f64  ┆ f64  │
     ╞══════╪══════╪══════╪══════╡
     │ null ┆ 1.0  ┆ 1.0  ┆ 1.0  │
-    ├╌╌╌╌╌╌┼╌╌╌╌╌╌┼╌╌╌╌╌╌┼╌╌╌╌╌╌┤
     │ null ┆ 2.0  ┆ 2.0  ┆ 2.0  │
-    ├╌╌╌╌╌╌┼╌╌╌╌╌╌┼╌╌╌╌╌╌┼╌╌╌╌╌╌┤
     │ null ┆ null ┆ 3.0  ┆ 3.0  │
-    ├╌╌╌╌╌╌┼╌╌╌╌╌╌┼╌╌╌╌╌╌┼╌╌╌╌╌╌┤
     │ null ┆ null ┆ null ┆ 99.9 │
     └──────┴──────┴──────┴──────┘
 
@@ -2230,7 +2583,6 @@ def from_epoch(
     │ datetime[μs]        │
     ╞═════════════════════╡
     │ 2022-10-25 07:31:17 │
-    ├╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌╌┤
     │ 2022-10-25 07:31:39 │
     └─────────────────────┘
 
