@@ -1,5 +1,6 @@
 from __future__ import annotations
 
+import typing
 from typing import Any, Sequence
 
 try:
@@ -13,17 +14,13 @@ from polars import internals as pli
 
 
 class WhenThenThen:
-    """
-    Utility class. See the `when` function.
-    """
+    """Utility class. See the `when` function."""
 
     def __init__(self, pywhenthenthen: Any):
         self.pywhenthenthen = pywhenthenthen
 
     def when(self, predicate: pli.Expr | bool) -> WhenThenThen:
-        """
-        Start another "when, then, otherwise" layer.
-        """
+        """Start another "when, then, otherwise" layer."""
         predicate = pli.expr_to_lit_or_expr(predicate)
         return WhenThenThen(self.pywhenthenthen.when(predicate._pyexpr))
 
@@ -46,6 +43,7 @@ class WhenThenThen:
         --------
         when : Start another when, then, otherwise layer.
         otherwise : Values to return in case of the predicate being `False`.
+
         """
         expr_ = pli.expr_to_lit_or_expr(expr)
         return WhenThenThen(self.pywhenthenthen.then(expr_._pyexpr))
@@ -63,23 +61,25 @@ class WhenThenThen:
         --------
         when : Start another when, then, otherwise layer.
         then : Values to return in case of the predicate being `True`.
+
         """
         expr = pli.expr_to_lit_or_expr(expr)
         return pli.wrap_expr(self.pywhenthenthen.otherwise(expr._pyexpr))
 
+    @typing.no_type_check
+    def __getattr__(self, item) -> pli.Expr:
+        expr = self.otherwise(None)  # noqa: F841
+        return eval(f"expr.{item}")
+
 
 class WhenThen:
-    """
-    Utility class. See the `when` function.
-    """
+    """Utility class. See the `when` function."""
 
     def __init__(self, pywhenthen: Any):
         self._pywhenthen = pywhenthen
 
     def when(self, predicate: pli.Expr | bool) -> WhenThenThen:
-        """
-        Start another "when, then, otherwise" layer.
-        """
+        """Start another "when, then, otherwise" layer."""
         predicate = pli.expr_to_lit_or_expr(predicate)
         return WhenThenThen(self._pywhenthen.when(predicate._pyexpr))
 
@@ -91,15 +91,19 @@ class WhenThen:
         --------
         when : Start another when, then, otherwise layer.
         then : Values to return in case of the predicate being `True`.
+
         """
         expr = pli.expr_to_lit_or_expr(expr)
         return pli.wrap_expr(self._pywhenthen.otherwise(expr._pyexpr))
 
+    @typing.no_type_check
+    def __getattr__(self, item) -> pli.Expr:
+        expr = self.otherwise(None)  # noqa: F841
+        return eval(f"expr.{item}")
+
 
 class When:
-    """
-    Utility class. See the `when` function.
-    """
+    """Utility class. See the `when` function."""
 
     def __init__(self, pywhen: pywhen):
         self._pywhen = pywhen
@@ -123,6 +127,7 @@ class When:
         --------
         when : Start another when, then, otherwise layer.
         otherwise : Values to return in case of the predicate being `False`.
+
         """
         expr = pli.expr_to_lit_or_expr(expr)
         pywhenthen = self._pywhen.then(expr._pyexpr)
@@ -135,7 +140,8 @@ def when(expr: pli.Expr | bool) -> When:
 
     Examples
     --------
-    Below we add a column with the value 1, where column "foo" > 2 and the value -1 where it isn't.
+    Below we add a column with the value 1, where column "foo" > 2 and the value -1
+    where it isn't.
 
     >>> df = pl.DataFrame({"foo": [1, 3, 4], "bar": [3, 4, 0]})
     >>> df.with_column(pl.when(pl.col("foo") > 2).then(pl.lit(1)).otherwise(pl.lit(-1)))
@@ -146,9 +152,7 @@ def when(expr: pli.Expr | bool) -> When:
     │ i64 ┆ i64 ┆ i32     │
     ╞═════╪═════╪═════════╡
     │ 1   ┆ 3   ┆ -1      │
-    ├╌╌╌╌╌┼╌╌╌╌╌┼╌╌╌╌╌╌╌╌╌┤
     │ 3   ┆ 4   ┆ 1       │
-    ├╌╌╌╌╌┼╌╌╌╌╌┼╌╌╌╌╌╌╌╌╌┤
     │ 4   ┆ 0   ┆ 1       │
     └─────┴─────┴─────────┘
 
@@ -168,9 +172,7 @@ def when(expr: pli.Expr | bool) -> When:
     │ i64 ┆ i64 ┆ i32     │
     ╞═════╪═════╪═════════╡
     │ 1   ┆ 3   ┆ 4       │
-    ├╌╌╌╌╌┼╌╌╌╌╌┼╌╌╌╌╌╌╌╌╌┤
     │ 3   ┆ 4   ┆ 1       │
-    ├╌╌╌╌╌┼╌╌╌╌╌┼╌╌╌╌╌╌╌╌╌┤
     │ 4   ┆ 0   ┆ 1       │
     └─────┴─────┴─────────┘
 
@@ -178,6 +180,7 @@ def when(expr: pli.Expr | bool) -> When:
     --------
     then : Values to return in case of the predicate being `True`.
     otherwise : Values to return in case of the predicate being `False`.
+
     """
     expr = pli.expr_to_lit_or_expr(expr)
     pw = pywhen(expr._pyexpr)
