@@ -1,8 +1,9 @@
-use crate::conversion::get_pyseq;
 use polars::prelude::*;
 use polars_core::utils::CustomIterTools;
 use pyo3::{PyAny, PyResult};
 
+use crate::conversion::get_pyseq;
+
 pub fn py_seq_to_list(name: &str, seq: &PyAny, dtype: &DataType) -> PyResult<Series> {
     let (seq, len) = get_pyseq(seq)?;
     let s = match dtype {
@@ -106,7 +107,7 @@ pub fn py_seq_to_list(name: &str, seq: &PyAny, dtype: &DataType) -> PyResult<Ser
             builder.finish().into_series()
         }
         dt => {
-            panic!("cannot create list array from {:?}", dt);
+            panic!("cannot create list array from {dt:?}");
         }
     };
 
