@@ -1,3 +1,4 @@
+# flake8: noqa: W291
 from __future__ import annotations
 
 import sys
@@ -14,7 +15,6 @@ import pytest
 import polars as pl
 from polars.datatypes import DTYPE_TEMPORAL_UNITS
 from polars.dependencies import zoneinfo
-from polars.exceptions import NoRowsReturned, TooManyRowsReturned
 from polars.internals.construction import iterable_to_pydf
 from polars.testing import assert_frame_equal, assert_series_equal
 from polars.testing.parametric import columns
@@ -892,42 +892,6 @@ def test_df_fold() -> None:
     assert df_width_one.fold(lambda s1, s2: s1).series_equal(df["a"])
 
 
-def test_row_tuple() -> None:
-    df = pl.DataFrame({"a": ["foo", "bar", "2"], "b": [1, 2, 3], "c": [1.0, 2.0, 3.0]})
-
-    # return row by index
-    assert df.row(0) == ("foo", 1, 1.0)
-    assert df.row(1) == ("bar", 2, 2.0)
-    assert df.row(-1) == ("2", 3, 3.0)
-
-    # return row by predicate
-    assert df.row(by_predicate=pl.col("a") == "bar") == ("bar", 2, 2.0)
-    assert df.row(by_predicate=pl.col("b").is_in([2, 4, 6])) == ("bar", 2, 2.0)
-
-    # expected error conditions
-    with pytest.raises(TooManyRowsReturned):
-        df.row(by_predicate=pl.col("b").is_in([1, 3, 5]))
-
-    with pytest.raises(NoRowsReturned):
-        df.row(by_predicate=pl.col("a") == "???")
-
-    # cannot set both 'index' and 'by_predicate'
-    with pytest.raises(ValueError):
-        df.row(0, by_predicate=pl.col("a") == "bar")
-
-    # must call 'by_predicate' by keyword
-    with pytest.raises(TypeError):
-        df.row(None, pl.col("a") == "bar")  # type: ignore[misc]
-
-    # cannot pass predicate into 'index'
-    with pytest.raises(TypeError):
-        df.row(pl.col("a") == "bar")  # type: ignore[arg-type]
-
-    # at least one of 'index' and 'by_predicate' must be set
-    with pytest.raises(ValueError):
-        df.row()
-
-
 def test_df_apply() -> None:
     df = pl.DataFrame({"a": ["foo", "bar", "2"], "b": [1, 2, 3], "c": [1.0, 2.0, 3.0]})
     out = df.apply(lambda x: len(x), None).to_series()
@@ -1033,7 +997,7 @@ def test_describe() -> None:
             "describe": ["count", "null_count", "mean", "std", "min", "max", "median"],
             "a": [3.0, 0.0, 2.2666667, 1.101514, 1.0, 3.0, 2.8],
             "b": [3.0, 1.0, 4.5, 0.7071067811865476, 4.0, 5.0, 4.5],
-            "c": [3.0, 0.0, None, None, 0.0, 1.0, None],
+            "c": [3.0, 0.0, 0.6666666666666666, 0.5773502588272095, 0.0, 1.0, 1.0],
             "d": ["3", "1", None, None, "b", "c", None],
             "e": ["3", "1", None, None, None, None, None],
             "f": ["3", "0", None, None, "2020-01-01", "2022-01-01", None],
@@ -1182,14 +1146,9 @@ def test_literal_series() -> None:
 
 
 def test_to_html(df: pl.DataFrame) -> None:
-    # check if it does not panic/ error
-    df._repr_html_()
-
-
-def test_rows() -> None:
-    df = pl.DataFrame({"a": [1, 2], "b": [1, 2]})
-    assert df.rows() == [(1, 1), (2, 2)]
-    assert df.reverse().rows() == [(2, 2), (1, 1)]
+    # check it does not panic/error, and appears to contain a table
+    html = df._repr_html_()
+    assert "<table" in html
 
 
 def test_rename(df: pl.DataFrame) -> None:
@@ -1387,10 +1346,10 @@ def test_reproducible_hash_with_seeds() -> None:
     seeds = (11, 22, 33, 44)
 
     # TODO: introduce a platform-stable string hash...
-    #  in the meantime, account for arm64 (mac) hash values to reduce noise
+    #  in the meantime, try to account for arm64 (mac) hash values to reduce noise
     expected = pl.Series(
         "s",
-        [8823051245921001677, 988796329533502010, 7528667241828618484]
+        [6629530352159708028, 15496313222292466864, 6048298245521876612]
         if platform.mac_ver()[-1] == "arm64"
         else [6629530352159708028, 988796329533502010, 6048298245521876612],
         dtype=pl.UInt64,
@@ -2519,3 +2478,44 @@ def test_init_physical_with_timezone() -> None:
                 datetime(2022, 10, 12, 21, 30, tzinfo=zoneinfo.ZoneInfo(tz_asia)),
             )
         ]
+
+
+def test_glimpse() -> None:
+    df = pl.DataFrame(
+        {
+            "a": [1.0, 2.8, 3.0],
+            "b": [4, 5, None],
+            "c": [True, False, True],
+            "d": [None, "b", "c"],
+            "e": ["usd", "eur", None],
+            "f": [date(2020, 1, 1), date(2021, 1, 2), date(2022, 1, 1)],
+        }
+    )
+    result = df.glimpse()
+
+    expected = """Rows: 3
+Columns: 6
+$ a <Float64> 1.0, 2.8, 3.0                                                                             
+$ b   <Int64> 4, 5, None                                                                                
+$ c <Boolean> True, False, True                                                                         
+$ d    <Utf8> None, b, c                                                                                
+$ e    <Utf8> usd, eur, None                                                                            
+$ f    <Date> 2020-01-01, 2021-01-02, 2022-01-01"""
+    assert result.strip() == expected
+
+
+def test_item() -> None:
+    df = pl.DataFrame({"a": [1]})
+    assert df.item() == 1
+
+    with pytest.raises(ValueError):
+        df = pl.DataFrame({"a": [1, 2]})
+        df.item()
+
+    with pytest.raises(ValueError):
+        df = pl.DataFrame({"a": [1], "b": [2]})
+        df.item()
+
+    with pytest.raises(ValueError):
+        df = pl.DataFrame({})
+        df.item()
