@@ -142,6 +142,31 @@ def test_join_asof_floats() -> None:
         "b_right": ["rrow1", "rrow2", "rrow3"],
     }
 
+    # with by argument
+    # 5740
+    df1 = pl.DataFrame(
+        {"b": np.linspace(0, 5, 7), "c": ["x" if i < 4 else "y" for i in range(7)]}
+    )
+    df2 = pl.DataFrame(
+        {
+            "val": [0, 2.5, 2.6, 2.7, 3.4, 4, 5],
+            "c": ["x", "x", "x", "y", "y", "y", "y"],
+        }
+    ).with_column(pl.col("val").alias("b"))
+    assert df1.join_asof(df2, on="b", by="c").to_dict(False) == {
+        "b": [
+            0.0,
+            0.8333333333333334,
+            1.6666666666666667,
+            2.5,
+            3.3333333333333335,
+            4.166666666666667,
+            5.0,
+        ],
+        "c": ["x", "x", "x", "x", "y", "y", "y"],
+        "val": [0.0, 0.0, 0.0, 2.5, 2.7, 4.0, 5.0],
+    }
+
 
 def test_join_asof_tolerance() -> None:
     df_trades = pl.DataFrame(
@@ -624,6 +649,40 @@ def test_asof_join_schema_5211() -> None:
     ) == {"today": pl.Int64, "next_friday": pl.Int64}
 
 
+def test_asof_join_schema_5684() -> None:
+    df_a = pl.DataFrame(
+        {
+            "id": [1],
+            "a": [1],
+            "b": [1],
+        }
+    ).lazy()
+
+    df_b = pl.DataFrame(
+        {
+            "id": [1, 1, 2],
+            "b": [3, -3, 6],
+        }
+    ).lazy()
+
+    q = (
+        df_a.join_asof(df_b, by="id", left_on="a", right_on="b")
+        .drop("b")
+        .join_asof(df_b, by="id", left_on="a", right_on="b")
+        .drop("b")
+    )
+
+    projected_result = q.select(pl.all()).collect()
+    result = q.collect()
+
+    assert projected_result.frame_equal(result)
+    assert (
+        q.schema
+        == projected_result.schema
+        == {"id": pl.Int64, "a": pl.Int64, "b_right": pl.Int64}
+    )
+
+
 @typing.no_type_check
 def test_streaming_joins() -> None:
     n = 100
@@ -652,7 +711,7 @@ def test_streaming_joins() -> None:
             dfa_pl.lazy()
             .join(dfb_pl.lazy(), on="a", how=how)
             .sort(["a", "b"])
-            .collect(allow_streaming=True)
+            .collect(streaming=True)
         )
 
         a = pl.from_pandas(pd_result).with_column(pl.all().cast(int)).sort(["a", "b"])
@@ -664,7 +723,7 @@ def test_streaming_joins() -> None:
             dfa_pl.lazy()
             .join(dfb_pl.lazy(), on=["a", "b"], how=how)
             .sort(["a", "b"])
-            .collect(allow_streaming=True)
+            .collect(streaming=True)
         )
 
         # we cast to integer because pandas joins creates floats
@@ -705,3 +764,35 @@ def test_join_asof_projection() -> None:
         "df2_date": [None, None, None, 20221012, 20221015],
         "df1_date": [20221011, 20221012, 20221013, 20221014, 20221016],
     }
+
+
+def test_asof_join_by_logical_types() -> None:
+    dates = (
+        pl.date_range(datetime(2022, 1, 1), datetime(2022, 1, 2), interval="2h")
+        .cast(pl.Datetime("ns"))
+        .head(9)
+    )
+    x = pl.DataFrame({"a": dates, "b": map(float, range(9)), "c": ["1", "2", "3"] * 3})
+    assert x.join_asof(x, on="b", by=["c", "a"]).to_dict(False) == {
+        "a": [
+            datetime(2022, 1, 1, 0, 0),
+            datetime(2022, 1, 1, 2, 0),
+            datetime(2022, 1, 1, 4, 0),
+            datetime(2022, 1, 1, 6, 0),
+            datetime(2022, 1, 1, 8, 0),
+            datetime(2022, 1, 1, 10, 0),
+            datetime(2022, 1, 1, 12, 0),
+            datetime(2022, 1, 1, 14, 0),
+            datetime(2022, 1, 1, 16, 0),
+        ],
+        "b": [0.0, 1.0, 2.0, 3.0, 4.0, 5.0, 6.0, 7.0, 8.0],
+        "c": ["1", "2", "3", "1", "2", "3", "1", "2", "3"],
+    }
+
+
+def test_join_panic_on_binary_expr_5915() -> None:
+    df_a = pl.DataFrame({"a": [1, 2, 3]}).lazy()
+    df_b = pl.DataFrame({"b": [1, 4, 9, 9, 0]}).lazy()
+
+    z = df_a.join(df_b, left_on=[(pl.col("a") + 1).cast(int)], right_on=[pl.col("b")])
+    assert z.collect().to_dict(False) == {"a": [4]}
